
*****************************************************************************
*****************************************************************************
**                             APPENDIX TABLE 2
*****************************************************************************
*****************************************************************************

*****************************************************************************
*                              		Kenya
*****************************************************************************

use clean_all.dta, clear

preserve
keep if country == 1

* keep only districts observed in 2013 and 2014
egen district_wave_tag = tag(id_district wave)
bysort id_district: egen district_n_waves = total(district_wave_tag)
keep if district_n_waves == 2

* regression-adjusted preschool attendance by cohort and wave
collapse age any_preschool [pw=weight], by(cohort wave)
sum any_preschool
gen overall_mean = r(mean)
gen any_preschool_centered = any_preschool - r(mean) 

gen wave2014 = (wave == 2014)
reg any_preschool_centered wave2014
gen adjusted_frac = any_preschool - _b[_cons] if wave == 2013
replace adjusted_frac = any_preschool - _b[_cons] - _b[wave2014] if wave == 2014
gen country=1
tempfile KERE
save `KERE'
restore

*****************************************************************************
*                                 Tanzania
*****************************************************************************

preserve
keep if country == 2 & wave < 2014 

* keep only districts observed in 2011, 2012, and 2013
egen district_wave_tag = tag(id_district wave)
bysort id_district: egen district_n_waves = total(district_wave_tag)
keep if district_n_waves == 3

* regression-adjusted preschool attendance by cohort and wave
collapse age any_preschool [pw=weight], by(cohort wave)
sum any_preschool
gen overall_mean = r(mean)
gen any_preschool_centered = any_preschool - r(mean) 

gen wave2012 = (wave == 2012)
gen wave2013 = (wave == 2013)
reg any_preschool_centered wave2012 wave2013
gen adjusted_frac = any_preschool - _b[_cons] if wave == 2011
replace adjusted_frac = any_preschool - _b[_cons] - _b[wave2012] if wave == 2012
replace adjusted_frac = any_preschool - _b[_cons] - _b[wave2013] if wave == 2013
gen country=2
tempfile TZRE
save `TZRE'
restore

*****************************************************************************
*                        combine results into table
*****************************************************************************

use `KERE', clear
append using `TZRE'

format adjusted_frac %9.2f
tab cohort wave if country == 1, sum(adjusted_frac) nost nof
tab cohort wave if country == 2, sum(adjusted_frac) nost nof

