**************************************************************************
**************************************************************************
**                          APPENDIX TABLE 3
**************************************************************************
**************************************************************************

use clean_all.dta, clear


* generate age groups & interactions
gen age_group = 0
replace age_group = 1 if age >= 10 & age <= 12
replace age_group = 2 if age >= 13 & age <= 16
gen pre_X_age1 = any_preschool*(age_group == 0)
gen pre_X_age2 = any_preschool*(age_group == 1)
gen pre_X_age3 = any_preschool*(age_group == 2)

* indicator for hh with variation
bysort id_mother: egen hh_mean_preschool = mean(any_preschool)
gen hh_with_variation = ((hh_mean_preschool != 0)*(hh_mean_preschool != 1))

preserve
keep id_mother hh_with_variation country weight id_district
duplicates drop id_mother, force
save hh_var_temp, replace
restore


*** CENTERING ***
recode birth_order (11 = 10) if country == 1 //only one obs
recode birth_order (15 13 = 12) if country == 2 //only 2 obs, no one on order 14

* generate dummies for all interactions
gen age_cohort = age*cohort
gen birthorder_female=birth_order*female

gen rural_pos_rainfall0=rural*pos_rainfall_shock_y0
gen rural_pos_rainfall1=rural*pos_rainfall_shock_y1
gen rural_pos_rainfall2=rural*pos_rainfall_shock_y2
gen rural_pos_rainfall3=rural*pos_rainfall_shock_y3
gen rural_pos_rainfall4=rural*pos_rainfall_shock_y4
gen rural_pos_rainfall5=rural*pos_rainfall_shock_y5
gen rural_pos_rainfall6=rural*pos_rainfall_shock_y6
gen rural_neg_rainfall0=rural*neg_rainfall_shock_y0
gen rural_neg_rainfall1=rural*neg_rainfall_shock_y1
gen rural_neg_rainfall2=rural*neg_rainfall_shock_y2
gen rural_neg_rainfall3=rural*neg_rainfall_shock_y3
gen rural_neg_rainfall4=rural*neg_rainfall_shock_y4
gen rural_neg_rainfall5=rural*neg_rainfall_shock_y5
gen rural_neg_rainfall6=rural*neg_rainfall_shock_y6

tab age, gen(dum_age)
tab cohort, gen(dum_cohort)
tab age_cohort, gen(dum_age_cohort)
tab wave, gen(dum_wave)
tab birth_order, gen(dum_birthorder)
tab birthorder_female, gen(dum_birthorder_female)
tab mothers_edu, gen(dum_mothers_edu)
tab rural_pos_rainfall0, gen(dum_rural_pos_rainfall0)
tab rural_pos_rainfall1, gen(dum_rural_pos_rainfall1)
tab rural_pos_rainfall2, gen(dum_rural_pos_rainfall2)
tab rural_pos_rainfall3, gen(dum_rural_pos_rainfall3)
tab rural_pos_rainfall4, gen(dum_rural_pos_rainfall4)
tab rural_pos_rainfall5, gen(dum_rural_pos_rainfall5)
tab rural_pos_rainfall6, gen(dum_rural_pos_rainfall6)
tab rural_neg_rainfall0, gen(dum_rural_neg_rainfall0)
tab rural_neg_rainfall1, gen(dum_rural_neg_rainfall1)
tab rural_neg_rainfall2, gen(dum_rural_neg_rainfall2)
tab rural_neg_rainfall3, gen(dum_rural_neg_rainfall3)
tab rural_neg_rainfall4, gen(dum_rural_neg_rainfall4)
tab rural_neg_rainfall5, gen(dum_rural_neg_rainfall5)
tab rural_neg_rainfall6, gen(dum_rural_neg_rainfall6)

tab rural, gen(dumr)
forval x = 0(1)6 {
gen dum_rural_meanlights1`x' = dumr1*mean_lights_y`x'
gen dum_rural_meanlights2`x' = dumr2*mean_lights_y`x'
gen dum_rural_meanlights3`x' = dumr3*mean_lights_y`x'
}

global controls3 = "dum_age* dum_cohort* dum_birthorder* female mean_lights* pos_rainfall* neg_rainfall*  dum_rural*  "


preserve
*** HIGHEST GRADE ATTENDED ***
xtdata highest_grade_attended  pre_X_age* $controls3, fe clear
merge m:1 id_mother using hh_var_temp
keep if _merge == 3
drop _merge

* generate indicator variables for tables
gen age_X_cohort_fe = 1
gen district_fe = 1
gen sdcontrols = 1
gen regincome = 1
gen hh_fe = 1

reg highest_grade_attended pre_X_age* if country == 1

eststo clear

*** FIRST PANEL: KENYA *** 
* highest grade: test table 3 column (4) with table 8 column (2)

qui eststo KE_grade_full: reg highest_grade_attended pre_X_age*  $controls3 i.age_X_cohort_fe i.sdcontrols i.regincome i.hh_fe [aw=weight]  if country == 1

qui eststo KE_grade_sub: reg highest_grade_attended pre_X_age* $controls3 i.age_X_cohort_fe i.sdcontrols i.regincome i.hh_fe  [aw=weight] if country == 1 & hh_with_variation == 1

qui suest KE_grade_full KE_grade_sub, vce(cluster id_district)

esttab KE_grade_full KE_grade_sub,  keep(pre_X_age*) varlabels(pre_X_age1 "7-9 years" pre_X_age2 "10-12 years" pre_X_age3 "13-16 years") ///
		mtitles("HGrade" "HGrade") label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)

		
test [KE_grade_full_mean]pre_X_age1 = [KE_grade_sub_mean]pre_X_age1
test [KE_grade_full_mean]pre_X_age2 = [KE_grade_sub_mean]pre_X_age2
test [KE_grade_full_mean]pre_X_age3 = [KE_grade_sub_mean]pre_X_age3


*** SECOND PANEL: TANZANIA *** 
* highest grade: test table 3 column (4) with table 8 column (2)

qui eststo TZ_grade_full: reg highest_grade_attended pre_X_age* $controls3  i.age_X_cohort_fe i.sdcontrols i.regincome i.hh_fe [aw=weight] if country == 2

qui eststo TZ_grade_sub: reg highest_grade_attended pre_X_age* $controls3  i.age_X_cohort_fe i.sdcontrols i.regincome i.hh_fe [aw=weight] if country == 2 & hh_with_variation == 1

qui suest TZ_grade_full TZ_grade_sub, vce(cluster id_district)


esttab TZ_grade_full TZ_grade_sub,  keep(pre_X_age*) varlabels(pre_X_age1 "7-9 years" pre_X_age2 "10-12 years" pre_X_age3 "13-16 years") ///
		mtitles("HGrade" "HGrade") label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)

test [TZ_grade_full_mean]pre_X_age1 = [TZ_grade_sub_mean]pre_X_age1
test [TZ_grade_full_mean]pre_X_age2 = [TZ_grade_sub_mean]pre_X_age2
test [TZ_grade_full_mean]pre_X_age3 = [TZ_grade_sub_mean]pre_X_age3

restore


preserve
*** MEAN SCORES ***

xtdata mean_score_std  pre_X_age* $controls3, fe clear
merge m:1 id_mother using hh_var_temp
keep if _merge == 3
drop _merge

* generate indicator variables for tables
gen age_X_cohort_fe = 1
gen district_fe = 1
gen sdcontrols = 1
gen regincome = 1
gen hh_fe = 1


*** FIRST PANEL: KENYA ***
* mean scores: test table 4 column (4) with table 8 column (4)

qui eststo KE_score_full: reg mean_score_std pre_X_age*  $controls3 i.age_X_cohort_fe i.sdcontrols i.regincome i.hh_fe [aw=weight] if country == 1

qui eststo KE_score_sub: reg mean_score_std pre_X_age* $controls3 i.age_X_cohort_fe i.sdcontrols i.regincome i.hh_fe  [aw=weight]  if country == 1 & hh_with_variation == 1

qui suest KE_score_full KE_score_sub , vce(cluster id_district)


esttab KE_score_full KE_score_sub,  keep(pre_X_age*) varlabels(pre_X_age1 "7-9 years" pre_X_age2 "10-12 years" pre_X_age3 "13-16 years") ///
		mtitles("Score" "Score") label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)

test [KE_score_full_mean]pre_X_age1 = [KE_score_sub_mean]pre_X_age1
test [KE_score_full_mean]pre_X_age2 = [KE_score_sub_mean]pre_X_age2
test [KE_score_full_mean]pre_X_age3 = [KE_score_sub_mean]pre_X_age3



*** SECOND PANEL: TANZANIA *** 

* mean scores: test table 4 column (4) with table 8 column (4)
qui eststo TZ_score_full: reg mean_score_std pre_X_age* $controls3 i.age_X_cohort_fe i.sdcontrols i.regincome i.hh_fe [aw=weight] if country == 2

qui eststo TZ_score_sub: reg mean_score_std pre_X_age* $controls3  i.age_X_cohort_fe i.sdcontrols i.regincome i.hh_fe [aw=weight] if country == 2 & hh_with_variation == 1

qui suest TZ_score_full TZ_score_sub, vce(cluster id_district)

esttab TZ_score_full TZ_score_sub,  keep(pre_X_age*) varlabels(pre_X_age1 "7-9 years" pre_X_age2 "10-12 years" pre_X_age3 "13-16 years") ///
		mtitles("Score" "Score") label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)

test [TZ_score_full_mean]pre_X_age1 = [TZ_score_sub_mean]pre_X_age1
test [TZ_score_full_mean]pre_X_age2 = [TZ_score_sub_mean]pre_X_age2
test [TZ_score_full_mean]pre_X_age3 = [TZ_score_sub_mean]pre_X_age3

restore
