**************************************************************************
**************************************************************************
**                             KENYA 2013
**************************************************************************
**************************************************************************

use KE13_hhld.dta, clear
renvars _all, lower


**************************************************************************
*                    technical and control variables                      
**************************************************************************

* technical variables
count 
sum weight 
gen wave=2013
gen str17 id_hh_str="KE"  + string(wave) + "X" + string(id_hh, "%08.0f") // make sure that household id is unique also across waves
tab id_district [aw=weight], mis 
tab testsample [aw=weight], mis 
recode testsample (4/99 . = 99)

* child characteristics
tab age [aw=weight], mis 
gen cohort = wave - age
tab gender [aw=weight], mis 
recode gender (1 = 0) (2 = 1), gen(female)
gsort id_hh_str -age
bysort id_hh_str: gen birth_order=_n 

* mother's characteristics
tab mothers_age [aw=weight], mis
tab mothers_edu [aw=weight], mis
clonevar mothers_edu_orig = mothers_edu
recode mothers_edu (2 3 = 1) (. = 99)
label define mothers_edu 1 "Some primary or more" 99 "missing", modify

* household head's characteristics
tab hh_edu [aw=weight], mis 
recode hh_edu (. = 9)
tab hh_gender [aw=weight], mis 
recode hh_gender (. = 9)
gen farming = 0
replace farming = 1 if source_income == 4
rename source_income income_source

* household size
tab hh_size [aw=weight], mis 

* household wealth: individual components
tab house_wall [aw=weight], mis
recode house_wall (2/9 = 0) (. = 99), gen(house_wall_mud)
tab house_lighting [aw=weight], mis 
tab asset_tv  [aw=weight], mis
tab asset_radio [aw=weight], mis
tab asset_computer [aw=weight], mis
tab asset_phone [aw=weight], mis
tab asset_bicycle [aw=weight], mis
tab asset_motorbike [aw=weight], mis
tab asset_car [aw=weight], mis

* add rural dummy
sort id_village
merge m:1 id_village using rural_ke13 
drop if _merge == 2 
replace rural = 99 if rural == . 


**************************************************************************
*                         treatment variables
**************************************************************************

tab years_preschool [aw=weight], mis // NOTE: some extreme values (up to 9 years) - generate winsorized variable
recode years_preschool (4/9 = 3), gen(years_preschool_winsorized)
recode years_preschool (1/9 = 1), gen(any_preschool)


**************************************************************************
*                          outcome variables
**************************************************************************

* math: make comparable across waves and countries
tab math [aw=weight], mis
tab age math [aw=weight], mis row nof // missing values mostly from 3-5 year-olds who were not supposed to be tested
recode math (1=0) (2=1) (3=2) (4=3) (5=4) (6=5) (7=6) (8=6)
label define mathnew 0 "Nothing" 1 "Counting" 2 "Numbers" 3 "Values" 4 "Addition" 5 "Subtraction" 6 "Multiplication"
label values math mathnew

* English
tab english [aw=weight], mis
tab age english [aw=weight], mis row nof
replace english = english-1
label define englishnew 0 "Nothing" 1 "Letter" 2 "Word" 3 "Paragraph" 4 "Story"
label values english englishnew

* Swahili
tab swahili, mis 
replace swahili = swahili - 1
label values swahili englishnew

* in school
gen in_school=enr_ans
replace in_school=1 if in_school==0 & preschool==1

* highest grade completed
tab enr_ans dropout 
gen highest_grade_completed = 0 if preschool==1
replace highest_grade_completed = grade-1 if highest_grade_completed==. & enr_ans==1
replace highest_grade_completed = dropout_class-1 if highest_grade_completed==. & dropout==1
tab highest_grade_completed 
recode highest_grade_completed (-1 = 0)

* school type
recode schooltype (3=99) (4=99)

* completed primary school
tab completed, mis
tab completed highest_grade_completed, mis 
replace completed = 1 if highest_grade_completed >= 7 & completed == .
replace completed = 0 if highest_grade_completed < 7 & completed == .


**************************************************************************
*                 keep only necessary variables and save
**************************************************************************

tempfile KE_2013_temp
keep age cohort female birth_order hh_size hh_edu hh_gender mothers_edu_orig mothers_edu mothers_age mealsperday farming income_source rural /// child & household characteristics
	 house_wall_mud house_lighting asset_tv asset_radio asset_computer asset_phone asset_car asset_bicycle asset_motorbike /// household wealth
	 years_preschool years_preschool_winsorized any_preschool /// treatment variables
	 math english swahili grade highest_grade_completed completed /// outcome variables
	 enr_ans in_school neverenrolled preschool dropout dropout_class dropout_year /// enrollment-related variables
	 wave id_village id_district id_regionname id_districtname id_hh_str testsample weight /// technical variables
	 tuition schooltype 
save `KE_2013_temp'


**************************************************************************
**************************************************************************
**                             KENYA 2014
**************************************************************************
**************************************************************************

use KE14_hhld.dta, clear
renvars _all, lower


**************************************************************************
*                    technical and control variables                      
**************************************************************************

* technical variables
count 
sum weight 
gen wave=2014
gen str17 id_hh_str="KE"  + string(wave) + "X" + string(id_hh, "%08.0f") 
tab id_district [aw=weight], mis 
tab testsample [aw=weight], mis 
recode testsample (4/99 . = 99)

* child characteristics
tab age [aw=weight], mis 
gen cohort=wave-age
tab gender [aw=weight], mis 
recode gender (1 = 0) (2 = 1), gen(female)
gsort id_hh_str -age
bysort id_hh_str: gen birth_order=_n 

* mother's characteristics
tab mothers_age [aw=weight], mis
tab mothers_edu [aw=weight], mis
clonevar mothers_edu_orig = mothers_edu
recode mothers_edu (2 3 = 1) (. = 99)
label define mothers_edu 1 "Some primary or more" 99 "missing", modify

* household head's characteristics
tab hh_edu [aw=weight], mis 
recode hh_edu (. = 9)
tab hh_gender [aw=weight], mis 
recode hh_gender (. = 9)

* household size
tab hh_size [aw=weight], mis 

* household wealth: individual components
tab house_wall [aw=weight]
recode house_wall (2/9 = 0) (. = 99), gen(house_wall_mud)
tab house_lighting [aw=weight], mis 
tab asset_tv  [aw=weight], mis
tab asset_radio [aw=weight], mis
tab asset_computer [aw=weight], mis
tab asset_phone [aw=weight], mis
tab asset_bicycle [aw=weight], mis
tab asset_motorbike [aw=weight], mis
tab asset_car [aw=weight], mis

* add rural dummy
sort id_village
merge m:1 id_village using rural_KE14 
drop if _merge == 2 
replace rural = 99 if rural == . 


**************************************************************************
*                         treatment variables
**************************************************************************

tab years_preschool [aw=weight] // NOTE: some extreme values (up to 9 years)
recode years_preschool (4/9 = 3), gen(years_preschool_winsorized)
recode years_preschool (1/99 = 1), gen(any_preschool)


**************************************************************************
*                          outcome variables
**************************************************************************

* math: make comparable across waves and countries
tab math [aw=weight], mis
tab age math [aw=weight], mis row nof // missing values mostly from 3-5 year-olds who were not supposed to be tested
recode math (1=0) (2=1) (3=2) (4=3) (5=4) (6=5) (7=6) (8=6)
label define mathnew 0 "Nothing" 1 "Counting" 2 "Numbers" 3 "Values" 4 "Addition" 5 "Subtraction" 6 "Multiplication"
label values math mathnew

* english
tab english [aw=weight], mis
tab age english [aw=weight], mis row nof
replace english = english-1
label define englishnew 0 "Nothing" 1 "Letter" 2 "Word" 3 "Paragraph" 4 "Story"
label values english englishnew

* Swahili
tab swahili, mis 
replace swahili = swahili - 1
label values swahili englishnew

* in school
gen in_school=enr_ans
replace in_school=1 if in_school==0 & preschool==1

* highest grade completed
tab enr_ans dropout 
gen highest_grade_completed = 0 if preschool==1
replace highest_grade_completed = grade-1 if highest_grade_completed==. & enr_ans==1
replace highest_grade_completed = dropout_class-1 if highest_grade_completed==. & dropout==1
tab highest_grade_completed 
recode highest_grade_completed (-1 = 0)

* completed primary school
tab completed, mis 
tab completed highest_grade_completed, mis 
replace completed = 1 if highest_grade_completed >= 7 & completed == .
replace completed = 0 if highest_grade_completed < 7 & completed == .

**************************************************************************
*                 keep only necessary variables and save
**************************************************************************

keep age cohort female birth_order hh_size hh_edu hh_gender mothers_edu_orig mothers_edu mothers_age mealsperday rural /// child & household characteristics
	 house_wall_mud house_lighting asset_tv asset_radio asset_computer asset_phone asset_car asset_bicycle asset_motorbike /// household wealth
	 years_preschool years_preschool_winsorized any_preschool /// treatment variables
	 math english swahili grade highest_grade_completed completed /// outcome variables
	 enr_ans in_school neverenrolled preschool dropout dropout_class dropout_year /// enrollment-related variables
	 wave id_village id_district id_regionname id_districtname id_hh_str testsample weight /// technical variables
	 tuition  schooltype 
	 

**************************************************************************
**************************************************************************
**         KENYA: APPEND WAVES AND MAKE SOME FINAL ADJUSTMENTS          **
**************************************************************************
**************************************************************************

* append 2013 wave
append using `KE_2013_temp'
count

* generate country identifier
gen country=1

* generate household wealth index
tab house_lighting, gen(hlight)
tab house_wall_mud, gen(hwall)
pca hwall* hlight* asset_tv asset_radio asset_computer asset_phone asset_car asset_bicycle asset_motorbike [aw=weight] // note: asset_* variables are all 0-1 (even though in the questionnaire they ask "how many")
predict hh_wealth
drop hlight* hwall*

* save dataset
saveold KE_clean.dta, replace

