
**************************************************************************
**************************************************************************
**                           TANZANIA 2011                              **
**************************************************************************
**************************************************************************

use TZ11_hhld.dta, clear
renvars _all, lower


**************************************************************************
*                    technical and control variables                      
**************************************************************************


* technical variables
gen wave=2011
duplicates report id_hh 
gen str17 id_hh_str="TZ"  + string(wave) + "X" + string(id_hh, "%08.0f") // make sure that household id is unique also across waves
tab id_district [aw=weight], mis 
egen x = group(id_district) 
sum x
drop x

rename hh64 testsample
tab testsample [aw=weight], mis 
recode testsample (. = 99)

* child characteristics
tab age [aw=weight], mis 
gen cohort = wave-age
tab gender [aw=weight], mis 
recode gender (1 = 0) (2 = 1), gen(female)
gsort id_hh_str -age
bysort id_hh_str: gen birth_order=_n 
recode schooltype (.=99)
sum school_distance 

* mother's characteristics
tab mothers_edu, mis 
clonevar mothers_edu_orig = mothers_edu
recode mothers_edu (2 3 = 1) (. = 99)
label define mothers_edu 1 "Some primary or more" 99 "missing", modify
gen mothers_age = 999 // not asked in this wave

* household head's characteristics
gen hh_edu = 99 
tab hh_gender [aw=weight], mis 
recode hh_gender (. = 9) 
gen farming = 0
replace farming = 1 if hh_occupation == 1

* household size
tab hh_size [aw=weight], mis 


* household wealth: individual components
tab house_wall [aw=weight], mis
recode house_wall (2/9 = 0) (. = 99), gen(house_wall_mud)
tab asset_tv  [aw=weight], mis
tab asset_radio [aw=weight], mis
tab asset_phone [aw=weight], mis
tab asset_bicycle [aw=weight], mis
tab asset_motorbike [aw=weight], mis
tab asset_car [aw=weight], mis

* urban - rual dummy
rename id_rural rural
replace rural = 99 if rural == .

**************************************************************************
*                         treatment variables
**************************************************************************

rename wenttopreschool any_preschool // no info on no. of years in this wave
tab any_preschool, mis 
tab preschool, mis


**************************************************************************
*                          outcome variables
**************************************************************************

* math: make comparable across waves and countries
tab math [aw=weight], mis 
tab age math [aw=weight], mis row nof
recode math (1=0) (2=1) (3=2) (4=3) (5=4) (6=5) (7=6) 
label define mathnew 0 "Nothing" 1 "Counting" 2 "Numbers" 3 "Values" 4 "Addition" 5 "Subtraction" 6 "Multiplication"
label values math mathnew

* English
tab english [aw=weight], mis 
tab age english [aw=weight], mis row nof 
replace english = english-1
label define englishnew 0 "Nothing" 1 "Letter" 2 "Word" 3 "Paragraph" 4 "Story"
label values english englishnew

* Swahili
tab swahili, mis 
replace swahili = swahili - 1
label values swahili englishnew

* in school
gen in_school=enr_ans
replace in_school=1 if in_school==0 & preschool==1

* highest grade completed
tab enr_ans dropout 
gen highest_grade_completed = 0 if preschool==1
replace highest_grade_completed = grade-1 if highest_grade_completed==. & enr_ans==1
replace highest_grade_completed = dropout_class-1 if highest_grade_completed==. & dropout==1
tab highest_grade_completed


**************************************************************************
*                 keep only necessary variables and save
**************************************************************************

tempfile TZ_2011_temp
keep age cohort female birth_order hh_size hh_edu hh_gender mothers_edu mothers_edu_orig mothers_age farming rural /// child & household characteristics
	 house_wall_mud asset_tv asset_radio asset_phone asset_car asset_bicycle asset_motorbike /// household wealth
	 any_preschool /// treatment variables
	 math english swahili grade highest_grade_completed /// outcome variables
	 enr_ans in_school neverenrolled schooltype preschool dropout dropout_class /// enrollment-related variables
	 wave id_regionname id_district id_districtname id_hh id_hh_str id_village testsample weight // technical variables
sort id_village
save `TZ_2011_temp'




**************************************************************************
**************************************************************************
**                           TANZANIA 2012                              **
**************************************************************************
**************************************************************************

use TZ12_hhld.dta, clear
renvars _all, lower


**************************************************************************
*                    technical and control variables                      
**************************************************************************

* technical variables
count
sum weight
gen wave=2012
duplicates report id_hh 
gen str17 id_hh_str="TZ"  + string(wave) + "X" + string(id_hh, "%08.0f") 
tab id_district [aw=weight], mis 

gen testsample = 99 

* child's characteristics
tab age [aw=weight], mis 
gen cohort = wave-age
tab gender [aw=weight], mis 
recode gender (1 = 0) (2 = 1), gen(female)
gsort id_hh_str -age
bysort id_hh_str: gen birth_order=_n 
recode schooltype (.=99)
sum school_distance 

* mother's characteristics
tab mothers_edu, mis
clonevar mothers_edu_orig = mothers_edu
recode mothers_edu (2 3 = 1) (. = 99)
label define mothers_edu 1 "Some primary or more" 99 "missing", modify
gen mothers_age = 999 

* household head's characteristics
tab hh_edu [aw=weight], mis 
recode hh_edu (. = 9)
tab hh_gender [aw=weight], mis 
recode hh_gender (. = 9) 
gen farming = 0
replace farming = 1 if hh_occupation == 1

* household size
tab hh_size [aw=weight], mis 

* household wealth: individual components
tab house_wall [aw=weight], mis
recode house_wall (2/9 = 0) (. = 99), gen(house_wall_mud)
tab asset_tv [aw=weight], mis
tab asset_radio [aw=weight], mis
tab asset_phone [aw=weight], mis
tab asset_bicycle [aw=weight], mis
tab asset_motorbike [aw=weight], mis
tab asset_car [aw=weight], mis

* urban - rual dummy
rename id_rural rural
replace rural = 99 if rural == .


**************************************************************************
*                         treatment variables
**************************************************************************

rename wenttopreschool any_preschool // no info on no. of years in this wave
tab any_preschool, mis 
tab preschool, mis 


**************************************************************************
*                          outcome variables
**************************************************************************

* math: make comparable across waves and countries
tab math [aw=weight], mis
tab age math [aw=weight], mis row nof 
recode math (1=0) (2=1) (3=2) (4=3) (5=4) (6=5) (7=6) 
label define mathnew 0 "Nothing" 1 "Counting" 2 "Numbers" 3 "Values" 4 "Addition" 5 "Subtraction" 6 "Multiplication"
label values math mathnew

* English
tab english [aw=weight], mis 
tab age english [aw=weight], mis row nof 
replace english = english-1
label define englishnew 0 "Nothing" 1 "Letter" 2 "Word" 3 "Paragraph" 4 "Story"
label values english englishnew

* Swahili
tab swahili, mis 
replace swahili = swahili - 1
label values swahili englishnew

* in school
gen in_school=enr_ans
replace in_school=1 if in_school==0 & preschool==1

* highest grade completed
tab enr_ans dropout 
gen highest_grade_completed = 0 if preschool==1
replace highest_grade_completed = grade-1 if highest_grade_completed==. & enr_ans==1
replace highest_grade_completed = dropout_class-1 if highest_grade_completed==. & dropout==1
tab highest_grade_completed 

* completed primary school
tab completed, mis 
tab completed highest_grade_completed, mis 
replace completed = 1 if highest_grade_completed >= 7 & completed == .
replace completed = 0 if highest_grade_completed < 7 & completed == . 

**************************************************************************
*                 keep only necessary variables and save
**************************************************************************

tempfile TZ_2012_temp
keep age cohort female birth_order hh_size hh_edu hh_gender mothers_edu_orig mothers_edu mothers_age farming rural /// child & household characteristics
 	 house_wall_mud asset_tv asset_radio asset_phone asset_car asset_bicycle asset_motorbike /// household wealth
	 any_preschool /// treatment variables
	 math english swahili  grade highest_grade_completed completed /// outcome variables
	 enr_ans in_school neverenrolled schooltype preschool dropout dropout_class /// enrollment-related variables
	 wave id_district id_regionname id_districtname id_hh id_hh_str id_village testsample weight // technical variables
sort id_village
save `TZ_2012_temp'



**************************************************************************
**************************************************************************
**                           TANZANIA 2013                              **
**************************************************************************
**************************************************************************

use TZ13_hhld.dta, clear
renvars _all, lower

**************************************************************************
*                    technical and control variables                      
**************************************************************************

* technical variables
count 
sum weight 
gen wave=2013
duplicates report id_hh 
gen str17 id_hh_str="TZ"  + string(wave) + "X" + string(id_hh, "%08.0f") 
tab id_district [aw=weight], mis 

gen testsample = 99 

* child's characteristics
tab age [aw=weight], mis 
gen cohort = wave-age
tab gender [aw=weight], mis 
recode gender (1 = 0) (2 = 1), gen(female)
gsort id_hh_str -age
bysort id_hh_str: gen birth_order=_n 
tab schooltype, mis
recode schooltype (.=99)

* mother's characteristics
tab mothers_edu_raw, mis
tab mothers_edu, mis
clonevar mothers_edu_orig = mothers_edu
recode mothers_edu (3 = 1) (. = 99)
label define mothers_edu 1 "Some primary or more" 99 "missing", modify
tab mothers_age, mis

* household head's characteristics
tab hh_edu [aw=weight], mis 
recode hh_edu (. = 9)
tab hh_gender [aw=weight], mis 
recode hh_gender (. = 9)
gen farming = 0
replace farming = 1 if income_source == 5

* household size
tab hh_size [aw=weight], mis 


* household wealth: individual components
tab house_wall [aw=weight], mis
recode house_wall (2/9 = 0) (. = 99), gen(house_wall_mud)
tab asset_tv  [aw=weight], mis
tab asset_radio [aw=weight], mis
tab asset_phone [aw=weight], mis
tab asset_bicycle [aw=weight], mis
tab asset_motorbike [aw=weight], mis
tab asset_car [aw=weight], mis

* urban - rual dummy 
gen rural = 99



**************************************************************************
*                         treatment variables
**************************************************************************

tab wenttopreschool [aw=weight], mis // NOTE: some extreme values (up to 14 years) - generate winsorized variable; no missing values!
recode wenttopreschool (3/14 = 2), gen(years_preschool_winsorized)
recode wenttopreschool (1/14 = 1), gen(any_preschool)
tab preschool, mis 


**************************************************************************
*                          outcome variables
**************************************************************************

* math: make comparable across waves and countries
tab math [aw=weight], mis 
tab age math [aw=weight], mis row nof 
recode math (1=0) (2=1) (3=2) (4=3) (5=4) (6=5) (7=6)
label define mathnew 0 "Nothing" 1 "Counting" 2 "Numbers" 3 "Values" 4 "Addition" 5 "Subtraction" 6 "Multiplication"
label values math mathnew

* English
tab english [aw=weight], mis 
tab age english [aw=weight], mis row nof 
replace english = english-1
label define englishnew 0 "Nothing" 1 "Letter" 2 "Word" 3 "Paragraph" 4 "Story"
label values english englishnew

* Swahili
tab swahili, mis 
replace swahili = swahili - 1
label values swahili englishnew

* in school
gen in_school=enr_ans
replace in_school=1 if in_school==0 & preschool==1

* highest grade completed
tab enr_ans dropout 
gen highest_grade_completed = 0 if preschool==1
replace highest_grade_completed = grade-1 if highest_grade_completed==. & enr_ans==1
replace highest_grade_completed = dropout_class-1 if highest_grade_completed==. & dropout==1
tab highest_grade_completed 

* completed primary school
tab completed, mis 
tab completed highest_grade_completed, mis 
replace completed = 1 if highest_grade_completed >= 7 & completed == .
replace completed = 0 if highest_grade_completed < 7 & completed == .

**************************************************************************
*                 keep only necessary variables and save
**************************************************************************

tempfile TZ_2013_temp
keep age cohort female birth_order hh_size hh_edu hh_gender mothers_edu_orig mothers_edu mothers_age mealsperday farming income_source rural /// child & household characteristics
	 house_wall_mud asset_tv asset_radio asset_phone asset_car asset_bicycle asset_motorbike /// household wealth
	 years_preschool years_preschool_winsorized any_preschool /// treatment variables
	 math english swahili  grade  highest_grade_completed completed /// outcome variables
	 enr_ans in_school neverenrolled schooltype preschool dropout dropout_class /// enrollment-related variables
	 wave id_district id_regionname id_districtname id_hh id_hh_str id_village testsample weight // technical variables
sort id_village
save `TZ_2013_temp'



**************************************************************************
**************************************************************************
**                           TANZANIA 2014                              **
**************************************************************************
**************************************************************************

use TZ14_hhld.dta, clear
renvars _all, lower


**************************************************************************
*                    technical and control variables                      
**************************************************************************

* technical variables
count 
sum weight 
gen wave=2014
duplicates report id_hh 
gen str17 id_hh_str="TZ"  + string(wave) + "X" + string(id_hh, "%08.0f") 
tab id_district [aw=weight], mis 

tab testsample [aw=weight], mis 
recode testsample (. = 99)

* child's characteristics
tab age [aw=weight], mis 
gen cohort = wave-age
tab gender [aw=weight], mis 
recode gender (1 = 0) (2 = 1), gen(female)
gsort id_hh_str -age
bysort id_hh_str: gen birth_order=_n 
tab schooltype, mis 
recode schooltype (.=99)

* mother's characteristics
tab mothers_edu_raw, mis
tab mothers_age, mis
tab mothers_edu, mis
clonevar mothers_edu_orig = mothers_edu
recode mothers_edu (3 = 1) (. = 99)
label define mothers_edu 1 "Some primary or more" 99 "missing", modify

* household head's characteristics
tab hh_edu [aw=weight], mis 
recode hh_edu (. = 9)
tab hh_gender [aw=weight], mis 
recode hh_gender (. = 9) 
gen farming = 0
replace farming = 1 if income_source == 5

* household size
tab hh_size [aw=weight], mis

* household wealth: individual components
tab house_wall [aw=weight], mis 
recode house_wall (2/9 = 0) (. = 99), gen(house_wall_mud)
tab asset_tv  [aw=weight], mis
tab asset_radio [aw=weight], mis
tab asset_phone [aw=weight], mis
tab asset_bicycle [aw=weight], mis
tab asset_motorbike [aw=weight], mis
tab asset_car [aw=weight], mis

* urban - rual dummy
gen rural = 99


**************************************************************************
*                         treatment variables
**************************************************************************

tab wenttopreschool [aw=weight], mis // NOTE: some extreme values (up to 16 years) - generate winsorized variable; no missing values!!!
recode wenttopreschool (3/16 = 2), gen(years_preschool_winsorized)
recode wenttopreschool (1/16 = 1), gen(any_preschool)
tab preschool, mis 


**************************************************************************
*                          outcome variables
**************************************************************************

* math: make comparable across waves and countries
tab math [aw=weight], mis 
tab age math [aw=weight], mis row nof 
recode math (1=0) (2=1) (3=2) (4=3) (5=4) (6=5) (7=6)
label define mathnew 0 "Nothing" 1 "Counting" 2 "Numbers" 3 "Values" 4 "Addition" 5 "Subtraction" 6 "Multiplication"
label values math mathnew

* English
tab english [aw=weight], mis 
tab age english [aw=weight], mis row nof 
replace english = english-1
label define englishnew 0 "Nothing" 1 "Letter" 2 "Word" 3 "Paragraph" 4 "Story"
label values english englishnew

* Swahili
tab swahili, mis 
replace swahili = swahili - 1
label values swahili englishnew

* in school
gen in_school=enr_ans
replace in_school=1 if in_school==0 & preschool==1

* highest grade completed
tab enr_ans dropout 
gen highest_grade_completed = 0 if preschool==1
replace highest_grade_completed = grade-1 if highest_grade_completed==. & enr_ans==1
replace highest_grade_completed = dropout_class-1 if highest_grade_completed==. & dropout==1
tab highest_grade_completed 

* completed primary school
tab completed, mis 
tab completed highest_grade_completed, mis 
replace completed = 1 if highest_grade_completed >= 7 & completed == .
replace completed = 0 if highest_grade_completed < 7 & completed == .


**************************************************************************
*                 keep only necessary variables and save
**************************************************************************

tempfile TZ_2014_temp
keep age cohort female birth_order hh_size hh_edu hh_gender mothers_edu_orig mothers_edu mothers_age mealsperday farming income_source rural /// child & household characteristics
	 house_wall_mud asset_tv asset_radio asset_phone asset_car asset_bicycle asset_motorbike /// household wealth
	 years_preschool years_preschool_winsorized any_preschool /// treatment variables
	 math english swahili  grade  highest_grade_completed completed /// outcome variables
	 enr_ans in_school neverenrolled schooltype preschool dropout dropout_class /// enrollment-related variables
	 wave id_district id_regionname id_districtname id_hh id_hh_str id_village testsample weight /// technical variables
	 tuition // temp
sort id_region
save `TZ_2014_temp'


**************************************************************************
**************************************************************************
**       TANZANIA: APPEND WAVES AND MAKE SOME FINAL ADJUSTMENTS         **
**************************************************************************
**************************************************************************

* append 2011-2013 waves
append using `TZ_2013_temp'
append using `TZ_2012_temp'
append using `TZ_2011_temp'
count //352,676 children

* generate country identifier
gen country=2

* generate household wealth index
tab house_wall_mud, gen(hwall)
pca hwall* asset_tv asset_radio asset_phone asset_car asset_bicycle asset_motorbike [aw=weight] // note: asset_* variables are all 0-1 (even though in the questionnaire they ask "how many")
predict hh_wealth
drop hwall*

* correct weights for 2014
tab wave
tab wave [aw=weight]
gen one=1
gen weight_old=weight
tempfile district_weights_2012
tempfile district_weights_2013
tempfile district_weights_2014
	
forvalues w = 2012(1)2014 {	
	
	preserve
	collapse (sum) district_weight_`w'=one [pw=weight] if wave==`w', by(id_district)
	*list id_district district_weight_`w'
	save `district_weights_`w''
	restore

	merge m:1 id_district using `district_weights_`w'', nogen
}

egen district_tag=tag(id_district)
list district_weight_2013 district_weight_2014 if district_tag ==1

tab id_district wave // take 2013 weights for all districts but 406, which was not sampled in 2013; for 406, take 2012 wave instead
gen aux=weight*(district_weight_2013/district_weight_2014) if wave==2014
replace aux=weight*(district_weight_2012/district_weight_2014) if id_district==406 & wave==2014

replace weight=aux if wave==2014


drop one district_weight* district_tag

tab wave
tab wave [aw=weight] 

* save dataset
saveold TZ_clean.dta, replace version(13)


