
**************************************************************************
**************************************************************************
**       PREPARE THE RAW NIGHT LIGHTS DATA EXPORTED FROM QGIS           **
**************************************************************************
**************************************************************************

use raw_night_lights_from_QGIS.dta

* create country variable as in Uwezo data
gen country = 1 if cntry_name == "Kenya"
replace country = 2 if cntry_name == "Tanzania"
keep country admin_name y*

* adjust district identifiers (for merging with Uwezo data)
gen id_district_IPUMS = "KE - " + admin_name if country == 1
replace id_district_IPUMS = "TZ - " + admin_name if country == 2

* rename variables and make 1 observation per district and year
renvars y*, postdrop(5)
reshape long y, i(id_district_IPUMS) j(year)
sort country id_district_IPUMS year
rename y year_mean_lights

* create night lights for year 2000 to use with heterogeneity analysis
preserve
keep if year == 2000
rename year_mean_lights lights_2000
keep id_district_IPUMS lights_2000
save lights_2000.dta, replace
restore

* define cohorts; for each cohort, define a range of early-life rainfall measures
sort country id_district_IPUMS year
gen cohort = year
gen mean_lights_y0 = ln(0.01 + year_mean_lights[_n-1]) if id_district_IPUMS[_n-1] == id_district_IPUMS & year[_n-1] == cohort-1
gen mean_lights_y1 = ln(0.01 + year_mean_lights)
gen mean_lights_y2 = ln(0.01 + year_mean_lights[_n+1]) if id_district_IPUMS[_n+1] == id_district_IPUMS & year[_n+1] == cohort+1
gen mean_lights_y3 = ln(0.01 + year_mean_lights[_n+2]) if id_district_IPUMS[_n+2] == id_district_IPUMS & year[_n+2] == cohort+2
gen mean_lights_y4 = ln(0.01 + year_mean_lights[_n+3]) if id_district_IPUMS[_n+3] == id_district_IPUMS & year[_n+3] == cohort+3
gen mean_lights_y5 = ln(0.01 + year_mean_lights[_n+4]) if id_district_IPUMS[_n+4] == id_district_IPUMS & year[_n+4] == cohort+4
gen mean_lights_y6 = ln(0.01 + year_mean_lights[_n+5]) if id_district_IPUMS[_n+5] == id_district_IPUMS & year[_n+5] == cohort+5

* drop unnecessary variables and save
drop admin_name year year_mean_lights
order country id_district_IPUMS cohort
save KE_TZ_night_lights.dta, replace

