

**************************************************************************
**************************************************************************
**         PREPARE THE RAW RAINFALL DATA EXPORTED FROM QGIS             **
**************************************************************************
**************************************************************************

use raw_rainfall_from_QGIS.dta

* create country variable as in Uwezo data
gen country = 1 if cntry_name == "Kenya"
replace country = 2 if cntry_name == "Tanzania"
keep country admin_name _y*

* adjust district identifiers (for merging with Uwezo data)
gen id_district_IPUMS = "KE - " + admin_name if country == 1
replace id_district_IPUMS = "TZ - " + admin_name if country == 2

* rename variables and make 1 observation per district and year
renvars _y*, postdrop(4)
renvars _y*, predrop(1)
reshape long y, i(id_district_IPUMS) j(year)
sort country id_district_IPUMS year
rename y year_mean_pre


* define positive and negative rainfall shocks (20th vs. 80th percentile)
gen neg_rainfall_shock = 0
gen pos_rainfall_shock = 0
levelsof id_district_IPUMS, local(dis)
foreach d of local dis {
	_pctile year_mean_pre if id_district_IPUMS == "`d'", p(20 80)
	replace neg_rainfall_shock = 1 if year_mean_pre < `r(r1)' & id_district_IPUMS == "`d'"
	replace pos_rainfall_shock = 1 if year_mean_pre > `r(r2)' & id_district_IPUMS == "`d'"
}

* define cohorts; for each cohort, define a range of early-life rainfall measures
sort country id_district_IPUMS year
gen cohort = year
foreach v in neg_rainfall_shock pos_rainfall_shock {
	gen `v'_y0 = `v'[_n-1] if id_district_IPUMS[_n-1] == id_district_IPUMS & year[_n-1] == cohort-1
	gen `v'_y1 = `v'
	gen `v'_y2 = `v'[_n+1] if id_district_IPUMS[_n+1] == id_district_IPUMS & year[_n+1] == cohort+1
	gen `v'_y3 = `v'[_n+2] if id_district_IPUMS[_n+2] == id_district_IPUMS & year[_n+2] == cohort+2
	gen `v'_y4 = `v'[_n+3] if id_district_IPUMS[_n+3] == id_district_IPUMS & year[_n+3] == cohort+3
	gen `v'_y5 = `v'[_n+4] if id_district_IPUMS[_n+4] == id_district_IPUMS & year[_n+4] == cohort+4
	gen `v'_y6 = `v'[_n+5] if id_district_IPUMS[_n+5] == id_district_IPUMS & year[_n+5] == cohort+5
}

* drop unnecessary variables and save
drop admin_name year year_mean_pre neg_rainfall_shock pos_rainfall_shock
order country id_district_IPUMS cohort
save KE_TZ_rainfall.dta, replace

