**************************************************************************
**************************************************************************
**                               FIGURE 1
**************************************************************************
**************************************************************************

use clean_all.dta, clear


* generate sets of control variables
global controls1 = "age##cohort i.wave"
global controls2 = "age##cohort i.wave birth_order##female age_span i.mothers_edu hh_size hh_wealth_std i.rural"
global controls3 = "age##cohort i.wave birth_order##female age_span i.mothers_edu hh_size hh_wealth_std i.rural##(i.neg_rainfall_shock_y* i.pos_rainfall_shock_y* c.mean_lights_y*)"

* estimate enrollment effects only for those observed with highest grade
count if highest_grade_attended != . & in_school == .
replace in_school = . if highest_grade_attended == .


**************************************************************************
* 		                  upper panel: Kenya
**************************************************************************

set scheme s2mono

* highest grade
qui xtreg highest_grade_attended b7.age##any_preschool $controls3 [aw=weight] if country == 1, fe cluster(id_district)
lincom 1.any_preschool
local est = `r(estimate)'
local se = `r(se)'
local lo = `est' - 1.965*`se'
local hi = `est' + 1.965*`se'
cap mat drop KE_grade
mat KE_grade = [`est', `lo', `hi']
forvalues a = 8(1)16 {
	lincom 1.any_preschool + `a'.age#1.any_preschool
	local est = `r(estimate)'
	local se = `r(se)'
	local lo = `est' - 1.965*`se'
	local hi = `est' + 1.965*`se'
	mat KE_grade = KE_grade\[`est', `lo', `hi']
}
preserve
clear
svmat KE_grade
gen age = _n+6
eclplot KE_grade1 KE_grade2 KE_grade3 age, title("Highest grade attended", size(large)) eplot(scatter) rplot(rcap) xlabel(7(1)16) ylabel(-.4(.2).2) /*yscale(r(-.55 .4))*/ yline(0) ///
					  xtitle(" " "Age", size(medlarge)) ytitle("Coefficient (95% CI)", height(4) size(medlarge)) graphregion(color(gs15)) plotregion(fcolor(white))  name(KE_grade, replace)
restore

* dropout
qui xtreg in_school b7.age##any_preschool $controls3 [aw=weight] if country == 1, fe cluster(id_district)
lincom 1.any_preschool
local est = `r(estimate)'
local se = `r(se)'
local lo = `est' - 1.965*`se'
local hi = `est' + 1.965*`se'
cap mat drop KE_dropout
mat KE_dropout = [`est', `lo', `hi']
forvalues a = 8(1)16 {
	lincom 1.any_preschool + `a'.age#1.any_preschool
	local est = `r(estimate)'
	local se = `r(se)'
	local lo = `est' - 1.965*`se'
	local hi = `est' + 1.965*`se'
	mat KE_dropout = KE_dropout\[`est', `lo', `hi']
}
preserve
clear
svmat KE_dropout
gen age = _n+6
eclplot KE_dropout1 KE_dropout2 KE_dropout3 age, title("Currently enrolled", size(large)) eplot(scatter) rplot(rcap) xlabel(7(1)16) ylabel(0(.02).04) /*yscale(r(-.05 .0025))*/ yline(0) ///
					  xtitle(" " "Age", size(medlarge)) ytitle("Coefficient (95% CI)", height(4) size(medlarge)) graphregion(color(gs15)) plotregion(fcolor(white)) nodraw name(KE_dropout, replace)
restore


**************************************************************************
*   	                  lower panel: Tanzania
**************************************************************************

* highest grade
qui xtreg highest_grade_attended b8.age##any_preschool $controls3 [aw=weight] if country == 2, fe cluster(id_district)
lincom 1.any_preschool
local est = `r(estimate)'
local se = `r(se)'
local lo = `est' - 1.965*`se'
local hi = `est' + 1.965*`se'
cap mat drop TZ_grade
mat TZ_grade = [`est', `lo', `hi']
forvalues a = 9(1)16 {
	lincom 1.any_preschool + `a'.age#1.any_preschool
	local est = `r(estimate)'
	local se = `r(se)'
	local lo = `est' - 1.965*`se'
	local hi = `est' + 1.965*`se'
	mat TZ_grade = TZ_grade\[`est', `lo', `hi']
}
preserve
clear
svmat TZ_grade
gen age = _n+7
eclplot TZ_grade1 TZ_grade2 TZ_grade3 age, title("Highest grade attended", size(large)) eplot(scatter) rplot(rcap) xlabel(7(1)16) ylabel(-.2(.2).4) /*yscale(r(-.55 .4))*/ yline(0) ///
					  xtitle(" " "Age", size(medlarge)) ytitle("Coefficient (95%CI)", height(4) size(medlarge)) graphregion(color(gs15)) plotregion(fcolor(white))  name(TZ_grade, replace) 
restore

* dropout
qui xtreg in_school b8.age##any_preschool $controls3 [aw=weight] if country == 2, fe cluster(id_district)
lincom 1.any_preschool
local est = `r(estimate)'
local se = `r(se)'
local lo = `est' - 1.965*`se'
local hi = `est' + 1.965*`se'
cap mat drop TZ_dropout
mat TZ_dropout = [`est', `lo', `hi']
forvalues a = 9(1)16 {
	lincom 1.any_preschool + `a'.age#1.any_preschool
	local est = `r(estimate)'
	local se = `r(se)'
	local lo = `est' - 1.965*`se'
	local hi = `est' + 1.965*`se'
	mat TZ_dropout = TZ_dropout\[`est', `lo', `hi']
}
preserve
clear
svmat TZ_dropout
gen age = _n+7
eclplot TZ_dropout1 TZ_dropout2 TZ_dropout3 age, title("Currently enrolled", size(large)) eplot(scatter) rplot(rcap) xlabel(7(1)16) ylabel(0(.03)0.12) yscale(r(-.005 .13)) yline(0) ///
					  xtitle(" " "Age", size(medlarge)) ytitle("Coefficient (95% CI)", height(4) size(medlarge)) graphregion(color(gs15)) plotregion(fcolor(white)) nodraw name(TZ_dropout, replace)
restore


**************************************************************************
*                        combine into one figure
**************************************************************************

graph combine KE_grade KE_dropout, cols(2) ysize(6) iscale(.75) title("Panel A: Kenya", size(medlarge)) name(panel_KE, replace) nodraw
graph combine TZ_grade TZ_dropout, cols(2) ysize(6) iscale(.75) title("Panel B: Tanzania", size(medlarge)) name(panel_TZ, replace) nodraw
graph combine panel_KE panel_TZ, cols(1)
graph export "figure1.pdf", replace

