**************************************************************************
**************************************************************************
**                              FIGURE 2
**************************************************************************
**************************************************************************

use clean_all.dta, clear


* generate sets of control variables
global controls1 = "age##cohort i.wave"
global controls2 = "age##cohort i.wave birth_order##female age_span i.mothers_edu hh_size hh_wealth_std i.rural"
global controls3 = "age##cohort i.wave birth_order##female age_span i.mothers_edu hh_size hh_wealth_std i.rural##(i.neg_rainfall_shock_y* i.pos_rainfall_shock_y* c.mean_lights_y*)"


**************************************************************************
* 		                  upper panel: Kenya
**************************************************************************

set scheme s2mono
set matsize 5000

* cognitive test score
qui xtreg mean_score_std b7.age##any_preschool $controls3 [aw=weight] if country == 1, fe cluster(id_district)
lincom 1.any_preschool
local est = `r(estimate)'
local se = `r(se)'
local lo = `est' - 1.965*`se'
local hi = `est' + 1.965*`se'
cap mat drop KE_score
mat KE_score = [`est', `lo', `hi']
forvalues a = 8(1)16 {
	lincom 1.any_preschool + `a'.age#1.any_preschool
	local est = `r(estimate)'
	local se = `r(se)'
	local lo = `est' - 1.965*`se'
	local hi = `est' + 1.965*`se'
	mat KE_score = KE_score\[`est', `lo', `hi']
}
preserve
clear
svmat KE_score
gen age = _n+6
eclplot KE_score1 KE_score2 KE_score3 age, title("Composite test score", size(large)) eplot(scatter) rplot(rcap) xlabel(7(1)16) ylabel(-.1(.1).2) yscale(r(-.175 .25)) yline(0) ///
					  xtitle(" " "Age", size(medlarge)) ytitle("Coefficient (95% CI)", height(4) size(medlarge)) graphregion(color(gs15)) plotregion(fcolor(white)) name(KE_score, replace) nodraw
restore

* indicator for basic literacy and numeracy
qui xtreg g2_lit_num b7.age##any_preschool $controls3 [aw=weight] if country == 1, fe cluster(id_district)
lincom 1.any_preschool
local est = `r(estimate)'
local se = `r(se)'
local lo = `est' - 1.965*`se'
local hi = `est' + 1.965*`se'
cap mat drop KE_basic_skills
mat KE_basic_skills = [`est', `lo', `hi']
forvalues a = 8(1)16 {
	lincom 1.any_preschool + `a'.age#1.any_preschool
	local est = `r(estimate)'
	local se = `r(se)'
	local lo = `est' - 1.965*`se'
	local hi = `est' + 1.965*`se'
	mat KE_basic_skills = KE_basic_skills\[`est', `lo', `hi']
}
preserve
clear
svmat KE_basic_skills
gen age=_n+6
eclplot KE_basic_skills1 KE_basic_skills2 KE_basic_skills3 age, title("Has 2nd-grade literacy and numeracy skills", size(large)) eplot(scatter) rplot(rcap) xlabel(7(1)16) ylabel(-.05(.05).1) yscale(r(-.06 .1)) yline(0) ///
					  xtitle(" " "Age", size(medlarge)) ytitle("Coefficient (95% CI)", height(4) size(medlarge)) graphregion(color(gs15)) plotregion(fcolor(white)) name(KE_basic_skills, replace) nodraw
restore


**************************************************************************
*   	                  lower panel: Tanzania
**************************************************************************

* cognitive test score
qui xtreg mean_score_std b8.age##any_preschool $controls3 [aw=weight] if country == 2, fe cluster(id_district)
lincom 1.any_preschool
local est = `r(estimate)'
local se = `r(se)'
local lo = `est' - 1.965*`se'
local hi = `est' + 1.965*`se'
cap mat drop TZ_score
mat TZ_score = [`est', `lo', `hi']
forvalues a = 9(1)16 {
	lincom 1.any_preschool + `a'.age#1.any_preschool
	local est = `r(estimate)'
	local se = `r(se)'
	local lo = `est' - 1.965*`se'
	local hi = `est' + 1.965*`se'
	mat TZ_score = TZ_score\[`est', `lo', `hi']
}
preserve
clear
svmat TZ_score
gen age = _n+7
eclplot TZ_score1 TZ_score2 TZ_score3 age, title("Composite test score", size(large)) eplot(scatter) rplot(rcap) xlabel(7(1)16) ylabel(-.1(.1).2) yscale(r(-.175 .25)) yline(0) ///
					  xtitle(" " "Age", size(medlarge)) ytitle("Coefficient (95% CI)", height(4) size(medlarge)) graphregion(color(gs15)) plotregion(fcolor(white)) name(TZ_score, replace) nodraw
restore

* indicator for basic literacy and numeracy
qui xtreg g2_lit_num b8.age##any_preschool $controls3 [aw=weight] if country == 2, fe cluster(id_district)
lincom 1.any_preschool
local est = `r(estimate)'
local se = `r(se)'
local lo = `est' - 1.965*`se'
local hi = `est' + 1.965*`se'
cap mat drop TZ_basic_skills
mat TZ_basic_skills = [`est', `lo', `hi']
forvalues a = 9(1)16 {
	lincom 1.any_preschool + `a'.age#1.any_preschool
	local est = `r(estimate)'
	local se = `r(se)'
	local lo = `est' - 1.965*`se'
	local hi = `est' + 1.965*`se'
	mat TZ_basic_skills = TZ_basic_skills\[`est', `lo', `hi']
}
preserve
clear
svmat TZ_basic_skills
gen age = _n+7
eclplot TZ_basic_skills1 TZ_basic_skills2 TZ_basic_skills3 age, title("Has 2nd-grade literacy and numeracy skills", size(large)) eplot(scatter) rplot(rcap) xlabel(7(1)16) ylabel(-.05(.05).1) yscale(r(-.06 .1)) yline(0) ///
					  xtitle(" " "Age", size(medlarge)) ytitle("Coefficient (95% CI)", height(4) size(medlarge)) graphregion(color(gs15)) plotregion(fcolor(white)) name(TZ_basic_skills, replace) nodraw
restore


**************************************************************************
*                        combine into one figure
**************************************************************************

graph combine KE_score KE_basic_skills, cols(2) ysize(6) iscale(.75) title("Panel A: Kenya", size(medlarge)) name(panel_KE, replace) nodraw
graph combine TZ_score TZ_basic_skills, cols(2) ysize(6) iscale(.75) title("Panel B: Tanzania", size(medlarge)) name(panel_TZ, replace) nodraw
graph combine panel_KE panel_TZ, cols(1)
graph export "figure2.pdf", replace
