*******************************************************************************
*******************************************************************************
**                                  TABLE 1
*******************************************************************************
*******************************************************************************

use clean_all.dta, clear

* prepare variables
recode mothers_edu (99 = .) 
tab mothers_edu, gen(edu_level)
label var edu_level1 " None"
label var edu_level2 " Some primary or more"

recode rural (99 = .), gen(rural_recode)
label var rural_recode "Rural location"

gen years_preschool_given_any = years_preschool_winsorized if any_preschool == 1
label var years_preschool_given_any "Years of preschool attended"

bysort id_mother: egen hh_mean_preschool = mean(any_preschool)
gen hh_with_variation=((hh_mean_preschool!=0)*(hh_mean_preschool!=1))
egen hh_tag = tag(id_mother)
tab hh_with_variation country

* sociodemographic characteristics
eststo clear

qui estpost sum age female age_span edu_level* hh_size hh_wealth_std rural_recode [aw=weight] if country == 1
est store ke_child

estpost sum age female age_span edu_level* hh_size hh_wealth_std rural_recode [aw=weight] if country == 2
est store tz_child

esttab ke_child tz_child, main(mean) aux(sd) label b(2) 

	
* local income shocks		
eststo clear

qui estpost sum n_neg_rainfall_shocks n_pos_rainfall_shocks total_mean_lights [aw=weight] if country == 1
est store ke_income

qui estpost sum n_neg_rainfall_shocks n_pos_rainfall_shocks total_mean_lights  [aw=weight] if country == 2
est store tz_income

esttab ke_income tz_income, main(mean) aux(sd) label b(2) 


* preschool attendance		
eststo clear

qui estpost sum any_preschool years_preschool_given_any [aw=weight] if country == 1
est store ke_pre

qui estpost sum any_preschool years_preschool_given_any [aw=weight] if country == 2
est store tz_pre

esttab ke_pre  tz_pre, main(mean) aux(sd) label b(2) 
		

* outcome variables
eststo clear
		
qui estpost sum highest_grade_attended in_school mean_score_std g2_lit_num [aw=weight] if country == 1
est store ke_score

qui estpost sum highest_grade_attended in_school mean_score_std g2_lit_num [aw=weight] if country == 2
est store tz_score

esttab ke_score  tz_score, main(mean) aux(sd) label b(2) 
