**************************************************************************
**************************************************************************
**                               TABLE 3
**************************************************************************
**************************************************************************

use clean_all.dta, clear

* generate indicator variables for tables
gen age_X_cohort_fe = 1
gen district_fe = 1
gen sdcontrols = 1
gen regincome = 1
gen hh_fe = 1

* generate sets of control variables
global controls1 = "age##cohort i.wave"
global controls2 = "age##cohort i.wave birth_order##female age_span i.mothers_edu hh_size hh_wealth_std i.rural"
global controls3 = "age##cohort i.wave birth_order##female age_span i.mothers_edu hh_size hh_wealth_std i.rural##(i.neg_rainfall_shock_y* i.pos_rainfall_shock_y* c.mean_lights_y*)"

* generate age groups & interactions
gen age_group = 0
replace age_group = 1 if age >= 10 & age <= 12
replace age_group = 2 if age >= 13 & age <= 16
gen pre_X_age1 = any_preschool*(age_group == 0)
gen pre_X_age2 = any_preschool*(age_group == 1)
gen pre_X_age3 = any_preschool*(age_group == 2)

* estimate enrollment effects only for those observed with highest grade
count if highest_grade_attended != . & in_school == . // 0
replace in_school = . if highest_grade_attended == .

*** FIRST PANEL: KENYA ***

eststo clear

qui eststo KE0: reg   highest_grade_attended pre_X_age* $controls1 i.age_X_cohort_fe [aw=weight] if country == 1, cluster(id_district)
qui test pre_X_age1 = pre_X_age2 = pre_X_age3
estadd scalar equal = `r(p)' 

qui eststo KE1: areg  highest_grade_attended pre_X_age* $controls1 i.age_X_cohort_fe i.district_fe [aw=weight] if country == 1, absorb(id_district) cluster(id_district)
qui test pre_X_age1 = pre_X_age2 = pre_X_age3
estadd scalar equal = `r(p)'  

qui eststo KE2: areg  highest_grade_attended pre_X_age* $controls2 i.age_X_cohort_fe i.district_fe i.sdcontrols [aw=weight] if country == 1, absorb(id_district) cluster(id_district)
qui test pre_X_age1 = pre_X_age2 = pre_X_age3
estadd scalar equal = `r(p)' 

qui eststo KE3: areg  highest_grade_attended pre_X_age* $controls3 i.age_X_cohort_fe i.district_fe i.sdcontrols i.regincome [aw=weight] if country == 1, absorb(id_district) cluster(id_district)
qui test pre_X_age1 = pre_X_age2 = pre_X_age3
estadd scalar equal = `r(p)'  

qui eststo KE4: xtreg highest_grade_attended pre_X_age* $controls3 i.age_X_cohort_fe i.sdcontrols i.regincome i.hh_fe [aw=weight] if country == 1, fe cluster(id_district)
qui test pre_X_age1 = pre_X_age2 = pre_X_age3
estadd scalar equal = `r(p)' 

qui eststo KE5: xtreg in_school				  pre_X_age* $controls3 i.age_X_cohort_fe i.sdcontrols i.regincome i.hh_fe [aw=weight] if country == 1, fe cluster(id_district)
qui test pre_X_age1 = pre_X_age2 = pre_X_age3
estadd scalar equal = `r(p)'  

esttab KE1 KE2 KE3 KE4 KE5, keep(pre_X_age*) varlabels(pre_X_age1 "7-9 years" pre_X_age2 "10-12 years" pre_X_age3 "13-16 years") ///
		indicate("District fixed effects = 1.district_fe" "Socio-demographic controls = 1.sdcontrols" "Regional income controls = 1.regincome" "Household fixed effects = 1.hh_fe") ///
		mtitles("HGrade" "HGrade" "HGrade" "HGrade") label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3) scalar(equal)


*** SECOND PANEL: TANZANIA ***	

qui eststo TZ0: reg   highest_grade_attended pre_X_age* $controls1 i.age_X_cohort_fe [aw=weight] if country == 2, cluster(id_district)
qui test pre_X_age1 = pre_X_age2 = pre_X_age3
estadd scalar equal = `r(p)'  

qui eststo TZ1: areg  highest_grade_attended pre_X_age* $controls1 i.age_X_cohort_fe i.district_fe [aw=weight] if country == 2, absorb(id_district) cluster(id_district)
qui test pre_X_age1 = pre_X_age2 = pre_X_age3
estadd scalar equal = `r(p)'  

qui eststo TZ2: areg  highest_grade_attended pre_X_age* $controls2 i.age_X_cohort_fe i.district_fe i.sdcontrols [aw=weight] if country == 2, absorb(id_district) cluster(id_district)
qui test pre_X_age1 = pre_X_age2 = pre_X_age3
estadd scalar equal = `r(p)' 

qui eststo TZ3: areg  highest_grade_attended pre_X_age* $controls3 i.age_X_cohort_fe i.district_fe i.sdcontrols i.regincome [aw=weight] if country == 2, absorb(id_district) cluster(id_district)
qui test pre_X_age1 = pre_X_age2 = pre_X_age3
estadd scalar equal = `r(p)'   

qui eststo TZ4: xtreg highest_grade_attended pre_X_age* $controls3 i.age_X_cohort_fe i.sdcontrols i.regincome i.hh_fe [aw=weight] if country == 2, fe cluster(id_district)
qui test pre_X_age1 = pre_X_age2 = pre_X_age3
estadd scalar equal = `r(p)' 

qui eststo TZ5: xtreg in_school				  pre_X_age* $controls3 i.age_X_cohort_fe i.sdcontrols i.regincome i.hh_fe [aw=weight] if country == 2, fe cluster(id_district)
qui test pre_X_age1 = pre_X_age2 = pre_X_age3
estadd scalar equal = `r(p)'  

esttab TZ0 TZ1 TZ2 TZ3 TZ4,  keep(pre_X_age*) varlabels(pre_X_age1 "8-9 years" pre_X_age2 "10-12 years" pre_X_age3 "13-16 years") ///
		indicate("District fixed effects = 1.district_fe" "Socio-demographic controls = 1.sdcontrols" "Regional income controls = 1.regincome" "Household fixed effects = 1.hh_fe") ///
		mtitles("HGrade" "HGrade" "HGrade" "HGrade") label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3) scalar(equal)
		
