**************************************************************************
**************************************************************************
**                               TABLE 5
**************************************************************************
**************************************************************************

use clean_all.dta, clear


* generate age groups and interactions
gen age_group=0
replace age_group=1 if age>=10 & age<=12
replace age_group=2 if age>=13 & age<=16
gen pre_X_age1 = any_preschool*(age_group == 0)
gen pre_X_age2 = any_preschool*(age_group == 1)
gen pre_X_age3 = any_preschool*(age_group == 2)

* generate interactions again (needed to trick esttab into displaying coefficients side by side)
gen alt_pre_X_age1 = any_preschool*(age_group == 0)
gen alt_pre_X_age2 = any_preschool*(age_group == 1)
gen alt_pre_X_age3 = any_preschool*(age_group == 2)

* generate set of controls
global controls3 = "age##cohort i.wave birth_order##female age_span i.mothers_edu hh_size hh_wealth_std i.rural##(i.neg_rainfall_shock_y* i.pos_rainfall_shock_y* c.mean_lights_y*)"


**************************************************************************
*                 HETEROGENEITY BY NO. OF YEARS ATTENDED 
**************************************************************************

* fix preschool varible
tab years_preschool_winsorized preschool if country == 1, mis // 2,271 children are in preschool but have years = 0 => set to 1 to place them into treatment group
tab years_preschool_winsorized preschool if country == 2, mis // around 1,900 children are in preschool but have years = 0 or years = . => set to 1
replace years_preschool_winsorized = 1 if preschool == 1 & inlist(years_preschool_winsorized, 0, .)

* generate interactions again (needed to trick esttab into displaying coefficients side by side)
gen alt_years_preschool_winsorized = years_preschool_winsorized
gen alt1_years_preschool_winsorized = years_preschool_winsorized

eststo clear

* highest grade completed
qui eststo KE_HG_years1: xtreg highest_grade_attended i.age_group##i.years_preschool_winsorized  $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo KE_HG_years2: xtreg highest_grade_attended i.age_group##i.alt_years_preschool_winsorized  $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo KE_HG_years3: xtreg highest_grade_attended i.age_group##i.alt1_years_preschool_winsorized  $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo TZ_HG_years1: xtreg highest_grade_attended i.age_group##i.years_preschool_winsorized $controls3 [aw = weight] if country == 2, fe cluster(id_district)
qui eststo TZ_HG_years2: xtreg highest_grade_attended i.age_group##i.alt_years_preschool_winsorized $controls3 [aw = weight] if country == 2, fe cluster(id_district)
qui eststo TZ_HG_years3: xtreg highest_grade_attended i.age_group##i.alt1_years_preschool_winsorized $controls3 [aw = weight] if country == 2, fe cluster(id_district)

esttab KE_HG_years* TZ_HG_years*, rename(1.years_preschool_winsorized 1.pre_X_age1 2.alt_years_preschool_winsorized 1.pre_X_age1 3.alt1_years_preschool_winsorized 1.pre_X_age1 ///
		1.age_group#1.years_preschool_winsorized 1.pre_X_age2 1.age_group#2.alt_years_preschool_winsorized 1.pre_X_age2 1.age_group#3.alt1_years_preschool_winsorized 1.pre_X_age2 ///
		2.age_group#1.years_preschool_winsorized 1.pre_X_age3 2.age_group#2.alt_years_preschool_winsorized 1.pre_X_age3 2.age_group#3.alt1_years_preschool_winsorized 1.pre_X_age3 ) ///
		keep(1.pre_X_age*) varlabels(1.pre_X_age1 "7-9 years" 1.pre_X_age2 "10-12 years" 1.pre_X_age3 "13-16 years") ///
		label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)


* enrollment
qui eststo KE_enrol_years1: xtreg in_school i.age_group##i.years_preschool_winsorized  $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo KE_enrol_years2: xtreg in_school i.age_group##i.alt_years_preschool_winsorized  $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo KE_enrol_years3: xtreg in_school i.age_group##i.alt1_years_preschool_winsorized  $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo TZ_enrol_years1: xtreg in_school i.age_group##i.years_preschool_winsorized $controls3 [aw = weight] if country == 2, fe cluster(id_district)
qui eststo TZ_enrol_years2: xtreg in_school i.age_group##i.alt_years_preschool_winsorized $controls3 [aw = weight] if country == 2, fe cluster(id_district)
qui eststo TZ_enrol_years3: xtreg in_school i.age_group##i.alt1_years_preschool_winsorized $controls3 [aw = weight] if country == 2, fe cluster(id_district)

esttab KE_enrol_years* TZ_enrol_years*, rename(1.years_preschool_winsorized 1.pre_X_age1 2.alt_years_preschool_winsorized 1.pre_X_age1 3.alt1_years_preschool_winsorized 1.pre_X_age1 ///
		1.age_group#1.years_preschool_winsorized 1.pre_X_age2 1.age_group#2.alt_years_preschool_winsorized 1.pre_X_age2 1.age_group#3.alt1_years_preschool_winsorized 1.pre_X_age2 ///
		2.age_group#1.years_preschool_winsorized 1.pre_X_age3 2.age_group#2.alt_years_preschool_winsorized 1.pre_X_age3 2.age_group#3.alt1_years_preschool_winsorized 1.pre_X_age3 ) ///
		keep(1.pre_X_age*) varlabels(1.pre_X_age1 "7-9 years" 1.pre_X_age2 "10-12 years" 1.pre_X_age3 "13-16 years") ///
		label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)


* composite test score
qui eststo KE_score_years1: xtreg mean_score_std i.age_group##i.years_preschool_winsorized  $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo KE_score_years2: xtreg mean_score_std i.age_group##i.alt_years_preschool_winsorized  $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo KE_score_years3: xtreg mean_score_std i.age_group##i.alt1_years_preschool_winsorized  $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo TZ_score_years1: xtreg mean_score_std i.age_group##i.years_preschool_winsorized $controls3 [aw = weight] if country == 2, fe cluster(id_district)
qui eststo TZ_score_years2: xtreg mean_score_std i.age_group##i.alt_years_preschool_winsorized $controls3 [aw = weight] if country == 2, fe cluster(id_district)
qui eststo TZ_score_years3: xtreg mean_score_std i.age_group##i.alt1_years_preschool_winsorized $controls3 [aw = weight] if country == 2, fe cluster(id_district)

esttab KE_score_years* TZ_score_years*, rename(1.years_preschool_winsorized 1.pre_X_age1 2.alt_years_preschool_winsorized 1.pre_X_age1 3.alt1_years_preschool_winsorized 1.pre_X_age1 ///
		1.age_group#1.years_preschool_winsorized 1.pre_X_age2 1.age_group#2.alt_years_preschool_winsorized 1.pre_X_age2 1.age_group#3.alt1_years_preschool_winsorized 1.pre_X_age2 ///
		2.age_group#1.years_preschool_winsorized 1.pre_X_age3 2.age_group#2.alt_years_preschool_winsorized 1.pre_X_age3 2.age_group#3.alt1_years_preschool_winsorized 1.pre_X_age3 ) ///
		keep(1.pre_X_age*) varlabels(1.pre_X_age1 "7-9 years" 1.pre_X_age2 "10-12 years" 1.pre_X_age3 "13-16 years") ///
		label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)

* second-grade skills
qui eststo KE_g2skills_years1: xtreg g2_lit_num i.age_group##i.years_preschool_winsorized  $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo KE_g2skills_years2: xtreg g2_lit_num i.age_group##i.alt_years_preschool_winsorized  $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo KE_g2skills_years3: xtreg g2_lit_num i.age_group##i.alt1_years_preschool_winsorized  $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo TZ_g2skills_years1: xtreg g2_lit_num i.age_group##i.years_preschool_winsorized $controls3 [aw = weight] if country == 2, fe cluster(id_district)
qui eststo TZ_g2skills_years2: xtreg g2_lit_num i.age_group##i.alt_years_preschool_winsorized $controls3 [aw = weight] if country == 2, fe cluster(id_district)
qui eststo TZ_g2skills_years3: xtreg g2_lit_num i.age_group##i.alt1_years_preschool_winsorized $controls3 [aw = weight] if country == 2, fe cluster(id_district)

esttab KE_g2skills_years* TZ_g2skills_years*, rename(1.years_preschool_winsorized 1.pre_X_age1 2.alt_years_preschool_winsorized 1.pre_X_age1 3.alt1_years_preschool_winsorized 1.pre_X_age1 ///
		1.age_group#1.years_preschool_winsorized 1.pre_X_age2 1.age_group#2.alt_years_preschool_winsorized 1.pre_X_age2 1.age_group#3.alt1_years_preschool_winsorized 1.pre_X_age2 ///
		2.age_group#1.years_preschool_winsorized 1.pre_X_age3 2.age_group#2.alt_years_preschool_winsorized 1.pre_X_age3 2.age_group#3.alt1_years_preschool_winsorized 1.pre_X_age3 ) ///
		keep(1.pre_X_age*) varlabels(1.pre_X_age1 "7-9 years" 1.pre_X_age2 "10-12 years" 1.pre_X_age3 "13-16 years") ///
		label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)


**************************************************************************
*                        HETEROGENEITY BY GENDER
**************************************************************************

* highest grade completed
qui eststo KE_HG_gender1: xtreg highest_grade_attended i.female##i.pre_X_age1 i.female##i.pre_X_age2 i.female##i.pre_X_age3 i.female##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo KE_HG_gender2: xtreg highest_grade_attended i.female##i.alt_pre_X_age1 i.female##i.alt_pre_X_age2 i.female##i.alt_pre_X_age3 i.female##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo TZ_HG_gender1: xtreg highest_grade_attended i.female##i.pre_X_age1 i.female##i.pre_X_age2 i.female##i.pre_X_age3 i.female##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)
qui eststo TZ_HG_gender2: xtreg highest_grade_attended i.female##i.alt_pre_X_age1 i.female##i.alt_pre_X_age2 i.female##i.alt_pre_X_age3 i.female##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)

esttab KE_HG_gender* TZ_HG_gender*, rename(1.female#1.alt_pre_X_age1 1.pre_X_age1 1.female#1.alt_pre_X_age2 1.pre_X_age2 1.female#1.alt_pre_X_age3 1.pre_X_age3) ///
		keep(1.pre_X_age*) varlabels(1.pre_X_age1 "7-9 years" 1.pre_X_age2 "10-12 years" 1.pre_X_age3 "13-16 years") ///
		label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)

* enrollment
qui eststo KE_enrol_gender1: xtreg in_school i.female##i.pre_X_age1 i.female##i.pre_X_age2 i.female##i.pre_X_age3 i.female##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo KE_enrol_gender2: xtreg in_school i.female##i.alt_pre_X_age1 i.female##i.alt_pre_X_age2 i.female##i.alt_pre_X_age3 i.female##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo TZ_enrol_gender1: xtreg in_school i.female##i.pre_X_age1 i.female##i.pre_X_age2 i.female##i.pre_X_age3 i.female##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)
qui eststo TZ_enrol_gender2: xtreg in_school i.female##i.alt_pre_X_age1 i.female##i.alt_pre_X_age2 i.female##i.alt_pre_X_age3 i.female##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)

esttab KE_enrol_gender* TZ_enrol_gender*, rename(1.female#1.alt_pre_X_age1 1.pre_X_age1 1.female#1.alt_pre_X_age2 1.pre_X_age2 1.female#1.alt_pre_X_age3 1.pre_X_age3) ///
		keep(1.pre_X_age*) varlabels(1.pre_X_age1 "7-9 years" 1.pre_X_age2 "10-12 years" 1.pre_X_age3 "13-16 years") ///
		label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)

* composite test score
qui eststo KE_score_gender1: xtreg mean_score_std i.female##i.pre_X_age1 i.female##i.pre_X_age2 i.female##i.pre_X_age3 i.female##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo KE_score_gender2: xtreg mean_score_std i.female##i.alt_pre_X_age1 i.female##i.alt_pre_X_age2 i.female##i.alt_pre_X_age3 i.female##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo TZ_score_gender1: xtreg mean_score_std i.female##i.pre_X_age1 i.female##i.pre_X_age2 i.female##i.pre_X_age3 i.female##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)
qui eststo TZ_score_gender2: xtreg mean_score_std i.female##i.alt_pre_X_age1 i.female##i.alt_pre_X_age2 i.female##i.alt_pre_X_age3 i.female##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)

esttab KE_score_gender* TZ_score_gender*, rename(1.female#1.alt_pre_X_age1 1.pre_X_age1 1.female#1.alt_pre_X_age2 1.pre_X_age2 1.female#1.alt_pre_X_age3 1.pre_X_age3) ///
		keep(1.pre_X_age*) varlabels(1.pre_X_age1 "7-9 years" 1.pre_X_age2 "10-12 years" 1.pre_X_age3 "13-16 years") ///
		label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)

* second-grade skills
qui eststo KE_g2skills_gender1: xtreg g2_lit_num i.female##i.pre_X_age1 i.female##i.pre_X_age2 i.female##i.pre_X_age3 i.female##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo KE_g2skills_gender2: xtreg g2_lit_num i.female##i.alt_pre_X_age1 i.female##i.alt_pre_X_age2 i.female##i.alt_pre_X_age3 i.female##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo TZ_g2skills_gender1: xtreg g2_lit_num i.female##i.pre_X_age1 i.female##i.pre_X_age2 i.female##i.pre_X_age3 i.female##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)
qui eststo TZ_g2skills_gender2: xtreg g2_lit_num i.female##i.alt_pre_X_age1 i.female##i.alt_pre_X_age2 i.female##i.alt_pre_X_age3 i.female##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)

esttab KE_g2skills_gender* TZ_g2skills_gender*, rename(1.female#1.alt_pre_X_age1 1.pre_X_age1 1.female#1.alt_pre_X_age2 1.pre_X_age2 1.female#1.alt_pre_X_age3 1.pre_X_age3) ///
		keep(1.pre_X_age*) varlabels(1.pre_X_age1 "7-9 years" 1.pre_X_age2 "10-12 years" 1.pre_X_age3 "13-16 years") ///
		label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)


**************************************************************************
*                  HETEROGENEITY BY MOTHER'S EDUCATION
**************************************************************************

* highest grade completed
qui eststo KE_HG_meduc1: xtreg highest_grade_attended i.mothers_edu##i.pre_X_age1 i.mothers_edu##i.pre_X_age2 i.mothers_edu##i.pre_X_age3 i.mothers_edu##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo KE_HG_meduc2: xtreg highest_grade_attended i.mothers_edu##i.alt_pre_X_age1 i.mothers_edu##i.alt_pre_X_age2 i.mothers_edu##i.alt_pre_X_age3 i.mothers_edu##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo TZ_HG_meduc1: xtreg highest_grade_attended i.mothers_edu##i.pre_X_age1 i.mothers_edu##i.pre_X_age2 i.mothers_edu##i.pre_X_age3 i.mothers_edu##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)
qui eststo TZ_HG_meduc2: xtreg highest_grade_attended i.mothers_edu##i.alt_pre_X_age1 i.mothers_edu##i.alt_pre_X_age2 i.mothers_edu##i.alt_pre_X_age3 i.mothers_edu##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)

esttab KE_HG_meduc* TZ_HG_meduc*, rename(1.mothers_edu#1.alt_pre_X_age1 1.pre_X_age1 1.mothers_edu#1.alt_pre_X_age2 1.pre_X_age2 1.mothers_edu#1.alt_pre_X_age3 1.pre_X_age3) ///
		keep(1.pre_X_age*) varlabels(1.pre_X_age1 "7-9 years" 1.pre_X_age2 "10-12 years" 1.pre_X_age3 "13-16 years") ///
		label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)

* enrollment
qui eststo KE_enrol_meduc1: xtreg in_school i.mothers_edu##i.pre_X_age1 i.mothers_edu##i.pre_X_age2 i.mothers_edu##i.pre_X_age3 i.mothers_edu##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo KE_enrol_meduc2: xtreg in_school i.mothers_edu##i.alt_pre_X_age1 i.mothers_edu##i.alt_pre_X_age2 i.mothers_edu##i.alt_pre_X_age3 i.mothers_edu##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo TZ_enrol_meduc1: xtreg in_school i.mothers_edu##i.pre_X_age1 i.mothers_edu##i.pre_X_age2 i.mothers_edu##i.pre_X_age3 i.mothers_edu##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)
qui eststo TZ_enrol_meduc2: xtreg in_school i.mothers_edu##i.alt_pre_X_age1 i.mothers_edu##i.alt_pre_X_age2 i.mothers_edu##i.alt_pre_X_age3 i.mothers_edu##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)

esttab KE_enrol_meduc* TZ_enrol_meduc*, rename(1.mothers_edu#1.alt_pre_X_age1 1.pre_X_age1 1.mothers_edu#1.alt_pre_X_age2 1.pre_X_age2 1.mothers_edu#1.alt_pre_X_age3 1.pre_X_age3) ///
		keep(1.pre_X_age*) varlabels(1.pre_X_age1 "7-9 years" 1.pre_X_age2 "10-12 years" 1.pre_X_age3 "13-16 years") ///
		label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)

* composite test score
qui eststo KE_score_meduc1: xtreg mean_score_std i.mothers_edu##i.pre_X_age1 i.mothers_edu##i.pre_X_age2 i.mothers_edu##i.pre_X_age3 i.mothers_edu##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo KE_score_meduc2: xtreg mean_score_std i.mothers_edu##i.alt_pre_X_age1 i.mothers_edu##i.alt_pre_X_age2 i.mothers_edu##i.alt_pre_X_age3 i.mothers_edu##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo TZ_score_meduc1: xtreg mean_score_std i.mothers_edu##i.pre_X_age1 i.mothers_edu##i.pre_X_age2 i.mothers_edu##i.pre_X_age3 i.mothers_edu##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)
qui eststo TZ_score_meduc2: xtreg mean_score_std i.mothers_edu##i.alt_pre_X_age1 i.mothers_edu##i.alt_pre_X_age2 i.mothers_edu##i.alt_pre_X_age3 i.mothers_edu##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)

esttab KE_score_meduc* TZ_score_meduc*, rename(1.mothers_edu#1.alt_pre_X_age1 1.pre_X_age1 1.mothers_edu#1.alt_pre_X_age2 1.pre_X_age2 1.mothers_edu#1.alt_pre_X_age3 1.pre_X_age3) ///
		keep(1.pre_X_age*) varlabels(1.pre_X_age1 "7-9 years" 1.pre_X_age2 "10-12 years" 1.pre_X_age3 "13-16 years") ///
		label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)
		
* second-grade skills
qui eststo KE_g2skills_meduc1: xtreg g2_lit_num i.mothers_edu##i.pre_X_age1 i.mothers_edu##i.pre_X_age2 i.mothers_edu##i.pre_X_age3 i.mothers_edu##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo KE_g2skills_meduc2: xtreg g2_lit_num i.mothers_edu##i.alt_pre_X_age1 i.mothers_edu##i.alt_pre_X_age2 i.mothers_edu##i.alt_pre_X_age3 i.mothers_edu##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo TZ_g2skills_meduc1: xtreg g2_lit_num i.mothers_edu##i.pre_X_age1 i.mothers_edu##i.pre_X_age2 i.mothers_edu##i.pre_X_age3 i.mothers_edu##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)
qui eststo TZ_g2skills_meduc2: xtreg g2_lit_num i.mothers_edu##i.alt_pre_X_age1 i.mothers_edu##i.alt_pre_X_age2 i.mothers_edu##i.alt_pre_X_age3 i.mothers_edu##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)

esttab KE_g2skills_meduc* TZ_g2skills_meduc*, rename(1.mothers_edu#1.alt_pre_X_age1 1.pre_X_age1 1.mothers_edu#1.alt_pre_X_age2 1.pre_X_age2 1.mothers_edu#1.alt_pre_X_age3 1.pre_X_age3) ///
		keep(1.pre_X_age*) varlabels(1.pre_X_age1 "7-9 years" 1.pre_X_age2 "10-12 years" 1.pre_X_age3 "13-16 years") ///
		label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)


**************************************************************************
*                 HETEROGENEITY BY NIGHT LIGHTS DENSITY
**************************************************************************

* create night lights variable

merge m:1 id_district_IPUMS using lights_2000.dta
keep if _merge == 3
drop _merge

preserve
duplicates drop id_district country, force

_pctile lights_2000 if country == 1, percentiles(85) 
gen urban_lights_KE = 0
replace urban_lights_KE = 1 if lights_2000 >= `r(r1)' & country == 1

_pctile lights_2000 if country == 2, p(85) 
gen urban_lights_TZ = 0
replace urban_lights_TZ = 1 if lights_2000 >= `r(r1)' & country == 2

keep id_district country urban_lights*
sort country id_district
tempfile lights_temp
save `lights_temp'
restore

merge m:1 country id_district using `lights_temp'
keep if _merge == 3
drop _merge

* highest grade completed
qui eststo KE_HG_urban_lights1: xtreg highest_grade_attended i.urban_lights_KE##i.pre_X_age1 i.urban_lights_KE##i.pre_X_age2 i.urban_lights_KE##i.pre_X_age3 i.urban_lights_KE##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo KE_HG_urban_lights2: xtreg highest_grade_attended i.urban_lights_KE##i.alt_pre_X_age1 i.urban_lights_KE##i.alt_pre_X_age2 i.urban_lights_KE##i.alt_pre_X_age3 i.urban_lights_KE##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo TZ_HG_urban_lights1: xtreg highest_grade_attended i.urban_lights_TZ##i.pre_X_age1 i.urban_lights_TZ##i.pre_X_age2 i.urban_lights_TZ##i.pre_X_age3 i.urban_lights_TZ##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)
qui eststo TZ_HG_urban_lights2: xtreg highest_grade_attended i.urban_lights_TZ##i.alt_pre_X_age1 i.urban_lights_TZ##i.alt_pre_X_age2 i.urban_lights_TZ##i.alt_pre_X_age3 i.urban_lights_TZ##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)

esttab KE_HG_urban_lights* TZ_HG_urban_lights*, rename(1.urban_lights_KE#1.alt_pre_X_age1 1.pre_X_age1 1.urban_lights_TZ#1.alt_pre_X_age1 1.pre_X_age1 1.urban_lights_KE#1.alt_pre_X_age2 1.pre_X_age2 1.urban_lights_TZ#1.alt_pre_X_age2 1.pre_X_age2 1.urban_lights_KE#1.alt_pre_X_age3 1.pre_X_age3 1.urban_lights_TZ#1.alt_pre_X_age3 1.pre_X_age3) ///
		keep(1.pre_X_age*) varlabels(1.pre_X_age1 "7-9 years" 1.pre_X_age2 "10-12 years" 1.pre_X_age3 "13-16 years") ///
		label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)

* enrollment
qui eststo KE_enrol_urban_lights1: xtreg in_school i.urban_lights_KE##i.pre_X_age1 i.urban_lights_KE##i.pre_X_age2 i.urban_lights_KE##i.pre_X_age3 i.urban_lights_KE##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo KE_enrol_urban_lights2: xtreg in_school i.urban_lights_KE##i.alt_pre_X_age1 i.urban_lights_KE##i.alt_pre_X_age2 i.urban_lights_KE##i.alt_pre_X_age3 i.urban_lights_KE##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo TZ_enrol_urban_lights1: xtreg in_school i.urban_lights_TZ##i.pre_X_age1 i.urban_lights_TZ##i.pre_X_age2 i.urban_lights_TZ##i.pre_X_age3 i.urban_lights_TZ##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)
qui eststo TZ_enrol_urban_lights2: xtreg in_school i.urban_lights_TZ##i.alt_pre_X_age1 i.urban_lights_TZ##i.alt_pre_X_age2 i.urban_lights_TZ##i.alt_pre_X_age3 i.urban_lights_TZ##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)

esttab KE_enrol_urban_lights* TZ_enrol_urban_lights*, rename(1.urban_lights_KE#1.alt_pre_X_age1 1.pre_X_age1 1.urban_lights_TZ#1.alt_pre_X_age1 1.pre_X_age1 1.urban_lights_KE#1.alt_pre_X_age2 1.pre_X_age2 1.urban_lights_TZ#1.alt_pre_X_age2 1.pre_X_age2 1.urban_lights_KE#1.alt_pre_X_age3 1.pre_X_age3 1.urban_lights_TZ#1.alt_pre_X_age3 1.pre_X_age3) ///
		keep(1.pre_X_age*) varlabels(1.pre_X_age1 "7-9 years" 1.pre_X_age2 "10-12 years" 1.pre_X_age3 "13-16 years") ///
		label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)

* composite test score
qui eststo KE_score_urban_lights1: xtreg mean_score_std i.urban_lights_KE##i.pre_X_age1 i.urban_lights_KE##i.pre_X_age2 i.urban_lights_KE##i.pre_X_age3 i.urban_lights_KE##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo KE_score_urban_lights2: xtreg mean_score_std i.urban_lights_KE##i.alt_pre_X_age1 i.urban_lights_KE##i.alt_pre_X_age2 i.urban_lights_KE##i.alt_pre_X_age3 i.urban_lights_KE##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo TZ_score_urban_lights1: xtreg mean_score_std i.urban_lights_TZ##i.pre_X_age1 i.urban_lights_TZ##i.pre_X_age2 i.urban_lights_TZ##i.pre_X_age3 i.urban_lights_TZ##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)
qui eststo TZ_score_urban_lights2: xtreg mean_score_std i.urban_lights_TZ##i.alt_pre_X_age1 i.urban_lights_TZ##i.alt_pre_X_age2 i.urban_lights_TZ##i.alt_pre_X_age3 i.urban_lights_TZ##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)

esttab KE_score_urban_lights* TZ_score_urban_lights*, rename(1.urban_lights_KE#1.alt_pre_X_age1 1.pre_X_age1 1.urban_lights_TZ#1.alt_pre_X_age1 1.pre_X_age1 1.urban_lights_KE#1.alt_pre_X_age2 1.pre_X_age2 1.urban_lights_TZ#1.alt_pre_X_age2 1.pre_X_age2 1.urban_lights_KE#1.alt_pre_X_age3 1.pre_X_age3 1.urban_lights_TZ#1.alt_pre_X_age3 1.pre_X_age3) ///
		keep(1.pre_X_age*) varlabels(1.pre_X_age1 "7-9 years" 1.pre_X_age2 "10-12 years" 1.pre_X_age3 "13-16 years") ///
		label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)

* second-grade skills
qui eststo KE_g2skills_urban_lights1: xtreg g2_lit_num i.urban_lights_KE##i.pre_X_age1 i.urban_lights_KE##i.pre_X_age2 i.urban_lights_KE##i.pre_X_age3 i.urban_lights_KE##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo KE_g2skills_urban_lights2: xtreg g2_lit_num i.urban_lights_KE##i.alt_pre_X_age1 i.urban_lights_KE##i.alt_pre_X_age2 i.urban_lights_KE##i.alt_pre_X_age3 i.urban_lights_KE##i.age_group $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo TZ_g2skills_urban_lights1: xtreg g2_lit_num i.urban_lights_TZ##i.pre_X_age1 i.urban_lights_TZ##i.pre_X_age2 i.urban_lights_TZ##i.pre_X_age3 i.urban_lights_TZ##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)
qui eststo TZ_g2skills_urban_lights2: xtreg g2_lit_num i.urban_lights_TZ##i.alt_pre_X_age1 i.urban_lights_TZ##i.alt_pre_X_age2 i.urban_lights_TZ##i.alt_pre_X_age3 i.urban_lights_TZ##i.age_group $controls3 [aw = weight] if country == 2, fe cluster(id_district)

esttab KE_g2skills_urban_lights* TZ_g2skills_urban_lights*, rename(1.urban_lights_KE#1.alt_pre_X_age1 1.pre_X_age1 1.urban_lights_TZ#1.alt_pre_X_age1 1.pre_X_age1 1.urban_lights_KE#1.alt_pre_X_age2 1.pre_X_age2 1.urban_lights_TZ#1.alt_pre_X_age2 1.pre_X_age2 1.urban_lights_KE#1.alt_pre_X_age3 1.pre_X_age3 1.urban_lights_TZ#1.alt_pre_X_age3 1.pre_X_age3) ///
		keep(1.pre_X_age*) varlabels(1.pre_X_age1 "7-9 years" 1.pre_X_age2 "10-12 years" 1.pre_X_age3 "13-16 years") ///
		label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)
		

