**************************************************************************
**************************************************************************
**                               TABLE 6
**************************************************************************
**************************************************************************

use clean_all.dta, clear


* generate age groups and interactions
gen age_group = 0
replace age_group = 1 if age >= 10 & age <= 12
replace age_group = 2 if age >= 13 & age <= 16
gen pre_X_age1 = any_preschool*(age_group == 0)
gen pre_X_age2 = any_preschool*(age_group == 1)
gen pre_X_age3 = any_preschool*(age_group == 2)

* replace missing info on highest grade (used as control, not outcome here)
replace highest_grade_attended = 99 if highest_grade_attended == . & mean_score_std != .

global controls3 = "age##cohort i.wave birth_order##female age_span i.mothers_edu hh_size hh_wealth_std i.rural##(i.neg_rainfall_shock_y* i.pos_rainfall_shock_y* c.mean_lights_y*)"

* regressions
qui eststo KE_XHG0_score: xtreg mean_score_std pre_X_age* $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo KE_XHG1_score: xtreg mean_score_std pre_X_age* i.highest_grade_attended $controls3 [aw = weight] if country == 1, fe cluster(id_district)

esttab KE_XHG0_score KE_XHG1_score, keep(pre_X_age*) varlabels(pre_X_age1 "7-9 years" pre_X_age2 "10-12 years" pre_X_age3 "13-16 years") ///
		mtitles("baseline" "control for HG") label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3) title("KENYA, outcome is composite test score")


qui eststo TZ_XHG0_score: xtreg mean_score_std pre_X_age* $controls3 [aw = weight] if country == 2, fe cluster(id_district)
qui eststo TZ_XHG1_score: xtreg mean_score_std pre_X_age* i.highest_grade_attended $controls3 [aw = weight] if country == 2, fe cluster(id_district)

esttab TZ_XHG0_score TZ_XHG1_score, keep(pre_X_age*) varlabels(pre_X_age1 "7-9 years" pre_X_age2 "10-12 years" pre_X_age3 "13-16 years") ///
		mtitles("baseline" "control for HG") label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3) title("Tanzania, outcome is composite test score")
