**************************************************************************
**************************************************************************
** 	                             TABLE 7
**************************************************************************
**************************************************************************

use clean_all.dta, clear


**************************************************************************
*                            prepare variables
**************************************************************************

* generate sets of control variables
global controls1 = "age##cohort i.wave"
global controls2 = "age##cohort i.wave birth_order##female age_span i.mothers_edu hh_size hh_wealth_std i.rural"
global controls3 = "age##cohort i.wave birth_order##female age_span i.mothers_edu hh_size hh_wealth_std i.rural##(i.neg_rainfall_shock_y* i.pos_rainfall_shock_y* c.mean_lights_y*)"

* generate age groups & interactions
gen age_group = 0
replace age_group = 1 if age >= 10 & age <= 12
replace age_group = 2 if age >= 13 & age <= 16
gen pre_X_age1 = any_preschool*(age_group == 0)
gen pre_X_age2 = any_preschool*(age_group == 1)
gen pre_X_age3 = any_preschool*(age_group == 2)

* private-school dummy
tab country schooltype, mis // 8.5 percent missing
recode schooltype (2 = 1) (1 = 0) (99 = .), gen(private_school)

* summary stats for tuition and private school
tab age_group tuition if country == 1 [aw=weight], row nof
tab age_group tuition if country == 2 [aw=weight], row nof
tab age_group private_school if country == 1 [aw=weight], row nof
tab age_group private_school if country == 2 [aw=weight], row nof


**************************************************************************
*                           regression table
**************************************************************************

*** FIRST PANEL: KENYA ***

eststo clear

qui eststo KE1: xtreg tuition pre_X_age* $controls3 [aw = weight] if country == 1, fe cluster(id_district)
qui eststo KE2: xtreg private_school pre_X_age* $controls3 [aw = weight] if country == 1, fe cluster(id_district)

esttab KE1 KE2, keep(pre_X_age*) varlabels(pre_X_age1 "7-9 years" pre_X_age2 "10-12 years" pre_X_age3 "13-16 years") ///
		mtitles("tuition" "priv scho") label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)



*** SECOND PANEL: TANZANIA ***	

qui eststo TZ1: xtreg tuition pre_X_age* $controls3 [aw = weight] if country == 2, fe cluster(id_district)
qui eststo TZ2: xtreg private_school pre_X_age* $controls3 [aw = weight] if country == 2, fe cluster(id_district)

esttab TZ1 TZ2, keep(pre_X_age*) varlabels(pre_X_age1 "7-9 years" pre_X_age2 "10-12 years" pre_X_age3 "13-16 years") ///
		mtitles("tuition" "priv scho") label compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)


