**************************************************************************
**************************************************************************
**                               TABLE 8
**************************************************************************
**************************************************************************

use clean_all.dta, clear

* define controls
global controls1 = "age##cohort i.wave i.id_district"
global controls3 = "birth_order##female age_span i.mothers_edu hh_size hh_wealth_std i.rural##(i.neg_rainfall_shock_y* i.pos_rainfall_shock_y* c.mean_lights_y*)"

* indicator for hh with variation
bysort id_mother: egen hh_mean_preschool = mean(any_preschool)
gen hh_with_variation = ((hh_mean_preschool != 0)*(hh_mean_preschool != 1))

* generate age groups & interactions
gen age_group = 0
replace age_group = 1 if age >= 10 & age <= 12
replace age_group = 2 if age >= 13 & age <= 16
gen pre_X_age1 = any_preschool*(age_group == 0)
gen pre_X_age2 = any_preschool*(age_group == 1)
gen pre_X_age3 = any_preschool*(age_group == 2)

* generate indicator variables for tables
gen age_X_cohort_fe = 1
gen district_fe = 1
gen sdcontrols = 1
gen regincome = 1
gen hh_fe = 1


**************************************************************************
*                                  Kenya
**************************************************************************

eststo clear

preserve
keep if country == 1
keep if hh_with_variation == 1

* highest grade: uncontrolled regression
qui eststo KE_coef1: reg highest_grade_attended pre_X_age* $controls1 i.age_X_cohort_fe i.district_fe [aw = weight], cluster(id_district)
estadd scalar rsquared = `e(r2)'

* highest grade: hh FE + controls, compute rmax
qui areg highest_grade_attended pre_X_age* $controls1 $controls3 [aw = weight], absorb(id_mother) cluster(id_district)
local rmax13 = min(1.3*`e(r2)', 1)
local rsq = `e(r2)'

* highest grade: hh FE + controls, compute delta 
psacalc delta pre_X_age3, rmax(`rmax13') mcontrol($controls1 pre_X_age1 pre_X_age2)
local delta3temp = `r(delta)'
qui eststo KE_coef2: xtreg highest_grade_attended pre_X_age* $controls1 $controls3 i.age_X_cohort_fe i.sdcontrols i.regincome i.hh_fe [aw = weight], fe cluster(id_district)
estadd scalar rsquared = `rsq'
estadd scalar delta_age3 = `delta3temp': KE_coef2

* composite score: uncontrolled regression
qui eststo KE_coef3: reg mean_score_std pre_X_age* $controls1 i.age_X_cohort_fe i.district_fe [aw = weight], cluster(id_district)
estadd scalar rsquared = `e(r2)'

* composite score: hh FE + controls, compute rmax
qui areg mean_score_std pre_X_age* $controls1 $controls3 [aw = weight], absorb(id_mother) cluster(id_district)
local rmax13 = min(1.3*`e(r2)', 1)
local rsq = `e(r2)'

* composite score: hh FE + controls, compute delta
psacalc delta pre_X_age3, rmax(`rmax13') mcontrol($controls1 pre_X_age1 pre_X_age2)
local delta3temp = `r(delta)'
qui eststo KE_coef4: xtreg mean_score_std pre_X_age* $controls1 $controls3 i.age_X_cohort_fe i.sdcontrols i.regincome i.hh_fe [aw = weight], fe cluster(id_district)
estadd scalar rsquared = `rsq'
estadd scalar delta_age3 = `delta3temp': KE_coef4

esttab KE_coef*, se stats(N rsquared delta_age3, ///
	fmt(%9.0fc %09.3fc %09.3fc))  keep(pre_X_age*) star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)

restore

		
**************************************************************************
*                              Tanzania
**************************************************************************

preserve
keep if country == 2
keep if hh_with_variation == 1

* highest grade: uncontrolled regression
qui eststo TZ_coef1: reg highest_grade_attended pre_X_age* $controls1 i.age_X_cohort_fe i.district_fe [aw = weight], cluster(id_district)
estadd scalar rsquared = `e(r2)'

* highest grade: hh FE + controls, compute rmax
qui areg highest_grade_attended pre_X_age* $controls1 $controls3 [aw = weight], absorb(id_mother) cluster(id_district)
local rmax13 = min(1.3*`e(r2)', 1)
local rsq = `e(r2)'

* highest grade: hh FE + controls, compute delta
psacalc delta pre_X_age3, rmax(`rmax13') mcontrol($controls1 pre_X_age1 pre_X_age2)
local delta3temp = `r(delta)'
qui eststo TZ_coef2: xtreg highest_grade_attended pre_X_age* $controls1 $controls3 i.age_X_cohort_fe i.sdcontrols i.regincome i.hh_fe [aw = weight], fe cluster(id_district)
estadd scalar rsquared = `rsq'
estadd scalar delta_age3 = `delta3temp': TZ_coef2

* composite score: uncontrolled regression
qui eststo TZ_coef3: reg mean_score_std pre_X_age* $controls1 i.age_X_cohort_fe i.district_fe [aw = weight], cluster(id_district)
estadd scalar rsquared = `e(r2)'

* composite score: hh FE + controls, compute rmax
qui areg mean_score_std pre_X_age* $controls1 $controls3 [aw = weight], absorb(id_mother) cluster(id_district)
local rmax13 = min(1.3*`e(r2)', 1)
local rsq = `e(r2)'

* composite score: hh FE + controls, compute delta
psacalc delta pre_X_age3, rmax(`rmax13') mcontrol($controls1 pre_X_age1 pre_X_age2)
local delta3temp = `r(delta)'
qui eststo TZ_coef4: xtreg mean_score_std pre_X_age* $controls1 $controls3 i.age_X_cohort_fe i.sdcontrols i.regincome i.hh_fe [aw = weight], fe cluster(id_district)
estadd scalar rsquared = `rsq'
estadd scalar delta_age3 = `delta3temp': TZ_coef4

esttab TZ_coef1 TZ_coef2 TZ_coef3 TZ_coef4, se stats(N r2 delta_age3, ///
		fmt(%9.0fc %09.3fc %09.3fc)) keep(pre_X_age*) star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)

restore
		


